@@ -552,7 +552,7 @@ void TestExpressionParser::arrayFunctionDereferencing()
     Declaration* decl = top->localDeclarations().last();
     IntegralType::Ptr type = decl->abstractType().cast<IntegralType>();
     QVERIFY(type);
-    QEXPECT_FAIL("", "we'd need advanced array support to know that [0] returns a int...", Continue);
+    QEXPECT_FAIL("", "we'd need advanced array support to know that [0] returns an int...", Continue);
     QCOMPARE(type->dataType(), static_cast<uint>(IntegralType::TypeInt));
     // fallback
     QCOMPARE(type->dataType(), static_cast<uint>(IntegralType::TypeMixed));
@@ -580,7 +580,7 @@ void TestExpressionParser::arrayLiteralDereferencing()
     Declaration* decl = top->localDeclarations().last();
     IntegralType::Ptr type = decl->abstractType().cast<IntegralType>();
     QVERIFY(type);
-    QEXPECT_FAIL("", "we'd need advanced array support to know that [0] returns a int...", Continue);
+    QEXPECT_FAIL("", "we'd need advanced array support to know that [0] returns an int...", Continue);
     QCOMPARE(type->dataType(), static_cast<uint>(IntegralType::TypeInt));
     // fallback
     QCOMPARE(type->dataType(), static_cast<uint>(IntegralType::TypeMixed));
