@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2013                                               *
+ *   copyright (C) 2002-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -20,7 +20,7 @@ class UMLWidget;
  * Used to determine rules for associations.
  *
  * @author Paul Hensgen
- * Bugs and comments to umbrello-devel@kde.org or http://bugs.kde.org
+ * Bugs and comments to umbrello-devel@kde.org or https://bugs.kde.org
  */
 class AssocRules
 {
@@ -41,16 +41,22 @@ public:
 
     static Uml::AssociationType::Enum isGeneralisationOrRealisation(UMLWidget* widgetA, UMLWidget* widgetB);
 
-private:
+    typedef enum {All, Java} Language;
+    typedef enum {Any, UML1, UML2 } Level;
 
-    struct Assoc_Rule {  ///< Structure to help determine association rules.
+private:
+    class Assoc_Rule {  ///< Structure to help determine association rules.
+    public:
+        bool isValid() const;
+        Language language;                 ///< language rule applies to
         Uml::AssociationType::Enum assoc_type;   ///< association type
         WidgetBase::WidgetType widgetA_type;    ///< type of role A widget
         WidgetBase::WidgetType widgetB_type;    ///< type of role B widget
         bool role;                         ///< role text
-        bool multiplicity;                 ///< multipliciy text on association
+        bool multiplicity;                 ///< multiplicity text on association
         bool bidirectional;                ///< can have an association of same type going between widget each way
         bool self;                         ///< association to self
+        Level level;                       ///< UML level
     };
 
     static Assoc_Rule m_AssocRules[];  ///< Container that holds all the rules.
