@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2014                                               *
+ *   copyright (C) 2002-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -13,6 +13,7 @@
 
 // local includes
 #include "debug_utils.h"
+#include "diagram_utils.h"
 #include "umldragdata.h"
 #include "idchangelog.h"
 #include "associationwidget.h"
@@ -195,7 +196,10 @@ bool UMLClipboard::paste(const QMimeData* data)
     UMLDoc *doc = UMLApp::app()->document();
 
     int codingType = UMLDragData::getCodingType(data);
-
+    if (codingType == 6
+            && UMLApp::app()->currentView()) {
+        return Diagram_Utils::importGraph(data, UMLApp::app()->currentView()->umlScene());
+    }
     QString mimeType = QLatin1String("application/x-uml-clip") + QString::number(codingType);
     uDebug() << "Pasting mimeType=" << mimeType << "data=" << data->data(mimeType);
 
@@ -267,7 +271,7 @@ void UMLClipboard::addRelatedWidgets()
  *
  * @param UMLWidgetList& widgets
  */
-void UMLClipboard::fillObjectListForWidgets(UMLWidgetList& widgets)
+void UMLClipboard::fillObjectListForWidgets(const UMLWidgetList& widgets)
 {
     // The order of the packages in the clip matters. So we collect
     // the packages and add them from the root package to the deeper levels
@@ -372,7 +376,7 @@ void UMLClipboard::setCopyType(UMLListViewItemList& selectedItems)
 
 /**
  * Searches the child items of a UMLListViewItem to
- * establish which Copy type is to be perfomed.
+ * establish which Copy type is to be performed.
  * @param item          parent of the children
  * @param withDiagrams  includes diagrams
  * @param withObjects   includes objects
@@ -488,7 +492,7 @@ bool UMLClipboard::pasteClip2(const QMimeData* data)
  * as a fallback-clip when clip 1, 2, 4 or 5 are not applicable. But that should
  * never happen.
  *
- * Todo: remove clip3 alltogether.
+ * Todo: remove clip3 altogether.
  *
  * @param data   mime type
  * @return       success flag
@@ -560,8 +564,7 @@ bool UMLClipboard::pasteClip4(const QMimeData* data)
             delete widget;
             objectAlreadyExists = true;
         } else {
-            if (currentScene->type() == Uml::DiagramType::Activity ||
-                currentScene->type() == Uml::DiagramType::State) {
+            if (currentScene->isActivityDiagram() || currentScene->isStateDiagram()) {
                 widget->setID(doc->assignNewID(widget->id()));
             }
         }
@@ -684,7 +687,7 @@ bool UMLClipboard::pasteClip5(const QMimeData* data)
                // if parent is not a UMLEnum, bail out immediately;
                if (!enumParent) {
                    result = false;
-                   uError() << "Parent is not an UMLEnum";
+                   uError() << "Parent is not a UMLEnum";
                    break;
                }
 
@@ -709,7 +712,7 @@ bool UMLClipboard::pasteClip5(const QMimeData* data)
                 // if parent is not a UMLEntity, bail out immediately;
                 if (!entityParent) {
                     result = false;
-                    uError() << "Parent is not an UMLEntity";
+                    uError() << "Parent is not a UMLEntity";
                     break;
                 }
                 UMLObject *exist = entityParent->findChildObject(obj->name(), UMLObject::ot_EntityAttribute);
