@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2003      Brian Thomas <thomas@mail630.gsfc.nasa.gov>   *
- *   copyright (C) 2004-2014                                               *
+ *   copyright (C) 2004-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -73,7 +73,7 @@ CodeClassField::~CodeClassField ()
  */
 void CodeClassField::setParentUMLObject (UMLObject * obj)
 {
-    UMLRole *role = dynamic_cast<UMLRole*>(obj);
+    UMLRole *role = obj->asUMLRole();
     if(role) {
         UMLAssociation * parentAssoc = role->parentAssociation();
         Uml::AssociationType::Enum atype = parentAssoc->getAssocType();
@@ -113,7 +113,7 @@ QString CodeClassField::getListObjectType()
 {
     if (!parentIsAttribute())
     {
-        UMLRole * role = dynamic_cast<UMLRole*>(getParentObject());
+        UMLRole * role = getParentObject()->asUMLRole();
         if (role)
             return getUMLObjectName(role->object());
     }
@@ -226,7 +226,7 @@ CodeClassFieldDeclarationBlock * CodeClassField::getDeclarationCodeBlock()
 /**
  * Load params from the appropriate XMI element node.
  */
-void CodeClassField::loadFromXMI (QDomElement & root)
+void CodeClassField::loadFromXMI1 (QDomElement & root)
 {
     setAttributesFromNode(root);
 }
@@ -247,12 +247,12 @@ void CodeClassField::setAttributesOnNode (QDomDocument & doc, QDomElement & cfEl
                                                                                : QLatin1String("false"));
     // record tag on declaration codeblock
     // which we will store in its own separate child node block
-    m_declCodeBlock->saveToXMI(doc, cfElem);
+    m_declCodeBlock->saveToXMI1(doc, cfElem);
 
     // now record the tags on our accessormethods
     Q_FOREACH(CodeAccessorMethod *method, m_methodVector)
     {
-        method->saveToXMI(doc, cfElem);
+        method->saveToXMI1(doc, cfElem);
     }
 }
 
@@ -286,14 +286,14 @@ void CodeClassField::setAttributesFromNode (QDomElement & root)
     while (!element.isNull()) {
         QString tag = element.tagName();
         if (tag == QLatin1String("ccfdeclarationcodeblock")) {
-            m_declCodeBlock->loadFromXMI(element);
+            m_declCodeBlock->loadFromXMI1(element);
         } else
             if (tag == QLatin1String("codeaccessormethod")) {
                 int type = element.attribute(QLatin1String("accessType"), QLatin1String("0")).toInt();
                 int role_id = element.attribute(QLatin1String("role_id"), QLatin1String("-1")).toInt();
                 CodeAccessorMethod * method = findMethodByType((CodeAccessorMethod::AccessorType) type, role_id);
                 if (method)
-                    method->loadFromXMI(element);
+                    method->loadFromXMI1(element);
                 else
                     uError()<<"Cannot load code accessor method for type:"<<type<<" which does not exist in this codeclassfield. Is XMI out-dated or corrupt?";
 
@@ -301,7 +301,7 @@ void CodeClassField::setAttributesFromNode (QDomElement & root)
                 if (tag == QLatin1String("header")) {
                     // this is treated in parent.. skip over here
                 } else
-                    uWarning()<<"ERROR: bad savefile? code classfield loadFromXMI got child element with unknown tag:"<<tag<<" ignoring node.";
+                    uWarning()<<"ERROR: bad savefile? code classfield loadFromXMI1 got child element with unknown tag:"<<tag<<" ignoring node.";
 
         node = element.nextSibling();
         element = node.toElement();
@@ -311,7 +311,7 @@ void CodeClassField::setAttributesFromNode (QDomElement & root)
 /**
  * Save the XMI representation of this object.
  */
-void CodeClassField::saveToXMI (QDomDocument & doc, QDomElement & root)
+void CodeClassField::saveToXMI1 (QDomDocument & doc, QDomElement & root)
 {
     QDomElement docElement = doc.createElement(QLatin1String("codeclassfield"));
 
@@ -323,20 +323,20 @@ void CodeClassField::saveToXMI (QDomDocument & doc, QDomElement & root)
 /**
  * Find the minimum number of things that can occur in an association
  * If mistakenly called on attribute CF's the default value of is "0"
- * is returned. Similarly, if the association (role) CF doesn't have a multiplicty
+ * is returned. Similarly, if the association (role) CF doesn't have a multiplicity
  * 0 is returned.
  */
 int CodeClassField::minimumListOccurances()
 {
     if (!parentIsAttribute())
     {
-        UMLRole * role = dynamic_cast<UMLRole*>(getParentObject());
+        UMLRole * role = getParentObject()->asUMLRole();
         if (!role) {
             uError() << "no valid parent object";
             return -1;
         }
         QString multi = role->multiplicity();
-        // ush. IF we had a multiplicty object, this would be much easier.
+        // ush. IF we had a multiplicity object, this would be much easier.
         if (!multi.isEmpty())
         {
             QString lowerBoundString = multi.remove(QRegExp(QLatin1String("\\.\\.\\d+$")));
@@ -351,20 +351,20 @@ int CodeClassField::minimumListOccurances()
 /**
  * Find the maximum number of things that can occur in an association
  * If mistakenly called on attribute CF's the default value of is "1"
- * is returned. If the association (role) CF doesn't have a multiplicty
+ * is returned. If the association (role) CF doesn't have a multiplicity
  * or has a "*" specified then '-1' (unbounded) is returned.
  */
 int CodeClassField::maximumListOccurances()
 {
     if (!parentIsAttribute())
     {
-        UMLRole * role = dynamic_cast<UMLRole*>(getParentObject());
+        UMLRole * role = getParentObject()->asUMLRole();
         if (!role) {
             uError() << "no valid parent object";
             return -1;
         }
         QString multi = role->multiplicity();
-        // ush. IF we had a multiplicty object, this would be much easier.
+        // ush. IF we had a multiplicity object, this would be much easier.
         if (!multi.isEmpty())
         {
             QString upperBoundString = multi.section(QRegExp(QLatin1String("(\\.\\.)")), 1);
@@ -430,7 +430,7 @@ CodeAccessorMethod * CodeClassField::findMethodByType (CodeAccessorMethod::Acces
         // argh. this wont work because "accessorType' doesn't inherit from QObject.
         if(m_methodMap->contains(type))
                 return ((*m_methodMap)[type]);
-        CodeAccessorMethod * obj = NULL;
+        CodeAccessorMethod * obj = 0;
     */
     if(role_id > 1 || role_id < 0)
     {
@@ -442,7 +442,7 @@ CodeAccessorMethod * CodeClassField::findMethodByType (CodeAccessorMethod::Acces
         // design.
         Q_FOREACH(CodeAccessorMethod *m, m_methodVector)
         {
-            UMLRole * role = dynamic_cast<UMLRole*>(m->getParentObject());
+            UMLRole * role = m->getParentObject()->asUMLRole();
             if(!role)
                 uError()<<"    FindMethodByType()  cant create role for method type:"<<m->getType()<<endl;
             if(role && m->getType() == type && role->role() == role_id)
@@ -451,7 +451,7 @@ CodeAccessorMethod * CodeClassField::findMethodByType (CodeAccessorMethod::Acces
 
     }
 
-    return (CodeAccessorMethod *) NULL;
+    return (CodeAccessorMethod *) 0;
 }
 
 void CodeClassField::initAccessorMethods()
@@ -527,7 +527,9 @@ void CodeClassField::updateContent()
             method->setWriteOutText(m_writeOutMethods);
         return;
     }
-    UMLRole * role = dynamic_cast<UMLRole*>(getParentObject());
+    UMLRole * role = getParentObject()->asUMLRole();
+    if (!role)
+        return;
     Uml::Changeability::Enum changeType = role->changeability();
     bool isSingleValue = fieldIsSingleValue();
     bool isEmptyRole = role->name().isEmpty() ? true : false;
@@ -620,7 +622,7 @@ bool CodeClassField::fieldIsSingleValue ()
     if(parentIsAttribute())
         return true;
 
-    UMLRole * role = dynamic_cast<UMLRole*>(getParentObject());
+    UMLRole * role = getParentObject()->asUMLRole();
     if(!role)
         return true; // it is really an attribute
 
@@ -640,7 +642,7 @@ void CodeClassField::initFields(bool inConstructor)
 {
     m_writeOutMethods = false;
     m_listClassName.clear();
-    m_declCodeBlock = NULL;
+    m_declCodeBlock = 0;
 
     // m_methodMap = new QMap<CodeAccessorMethod::AccessorType, CodeAccessorMethod *>;
 
@@ -665,4 +667,3 @@ void CodeClassField::finishInitialization()
     connect(getParentObject(), SIGNAL(modified()), this, SIGNAL(modified())); // child objects will trigger off this signal
 }
 
-#include "codeclassfield.moc"
