@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2003      Brian Thomas <thomas@mail630.gsfc.nasa.gov>   *
- *   copyright (C) 2004-2014                                               *
+ *   copyright (C) 2004-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -77,7 +77,7 @@ void CodeClassFieldDeclarationBlock::forceRelease()
 /**
  * Save the XMI representation of this object.
  */
-void CodeClassFieldDeclarationBlock::saveToXMI(QDomDocument & doc, QDomElement & elem)
+void CodeClassFieldDeclarationBlock::saveToXMI1(QDomDocument & doc, QDomElement & elem)
 {
     QDomElement docElement = doc.createElement(QLatin1String("ccfdeclarationcodeblock"));
     setAttributesOnNode(doc, docElement);
@@ -87,7 +87,7 @@ void CodeClassFieldDeclarationBlock::saveToXMI(QDomDocument & doc, QDomElement &
 /**
  * Load params from the appropriate XMI element node.
  */
-void CodeClassFieldDeclarationBlock::loadFromXMI (QDomElement & root)
+void CodeClassFieldDeclarationBlock::loadFromXMI1 (QDomElement & root)
 {
     setAttributesFromNode(root);
 }
@@ -139,8 +139,8 @@ void CodeClassFieldDeclarationBlock::syncToParent ()
     // the name of the role is not defined.
     if (!(getParentClassField()->parentIsAttribute()))
     {
-        UMLRole * parent = dynamic_cast<UMLRole*>(getParentObject());
-        if (parent == NULL)
+        UMLRole * parent = getParentObject()->asUMLRole();
+        if (parent == 0)
             return;
         if (parent->name().isEmpty())
         {
@@ -166,4 +166,3 @@ void CodeClassFieldDeclarationBlock::init (CodeClassField * parentCF)
     connect(m_parentclassfield, SIGNAL(modified()), this, SLOT(syncToParent()));
 }
 
-#include "codeclassfielddeclarationblock.moc"
