@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2003      Brian Thomas <thomas@mail630.gsfc.nasa.gov>   *
- *   copyright (C) 2004-2014                                               *
+ *   copyright (C) 2004-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -28,7 +28,7 @@
  */
 CodeDocument::CodeDocument () : CodeGenObjectWithTextBlocks(this),
     m_lastTagIndex(0), m_filename(QString()), m_fileExtension(QString()),
-    m_ID(QString()), m_pathName(QString()), m_package(NULL), m_writeOutCode(true)
+    m_ID(QString()), m_pathName(QString()), m_package(0), m_writeOutCode(true)
 {
     setHeader(new CodeComment(this));
     //  m_dialog = new CodeDocumentDialog();
@@ -278,7 +278,7 @@ QString CodeDocument::cleanName (const QString &name)
  */
 void CodeDocument::updateHeader ()
 {
-    //try to find a heading file (license, coments, etc) then extract its text
+    //try to find a heading file (license, comments, etc) then extract its text
     QString headingText = UMLApp::app()->commonPolicy()->getHeadingFile(getFileExtension());
 
     headingText.replace(QRegExp(QLatin1String("%filename%")), getFileName()+getFileExtension());
@@ -345,7 +345,7 @@ void CodeDocument::resetTextBlocks()
  * Load params from the appropriate XMI element node.
  * @param root   the starting point for loading
  */
-void CodeDocument::loadFromXMI (QDomElement & root)
+void CodeDocument::loadFromXMI1 (QDomElement & root)
 {
     setAttributesFromNode(root);
 }
@@ -373,7 +373,7 @@ void CodeDocument::setAttributesOnNode (QDomDocument & doc, QDomElement & docEle
     // set the a header
     // which we will store in its own separate child node block
     QDomElement commElement = doc.createElement(QLatin1String("header"));
-    getHeader()->saveToXMI(doc, commElement); // comment
+    getHeader()->saveToXMI1(doc, commElement); // comment
     docElement.appendChild(commElement);
 
     // doc codePolicy?
@@ -397,11 +397,11 @@ void CodeDocument::setAttributesFromNode (QDomElement & root)
             // suspecting pre-1.5.3 file format where the package name was
             // saved instead of the package ID.
             UMLObject *o = umldoc->findUMLObject(pkgStr);
-            m_package = dynamic_cast<UMLPackage*>(o);
+            m_package = o->asUMLPackage();
         }
-        if (m_package == NULL) {
+        if (m_package == 0) {
             UMLObject *o = umldoc->findObjectById(Uml::ID::fromString(pkgStr));
-            m_package = dynamic_cast<UMLPackage*>(o);
+            m_package = o->asUMLPackage();
         }
     }
     const QString trueStr = QLatin1String("true");
@@ -418,7 +418,7 @@ void CodeDocument::setAttributesFromNode (QDomElement & root)
         if (tag == QLatin1String("header")) {
             QDomNode cnode = element.firstChild();
             QDomElement celem = cnode.toElement();
-            getHeader()->loadFromXMI(celem);
+            getHeader()->loadFromXMI1(celem);
             break;
         }
         node = element.nextSibling();
@@ -434,7 +434,7 @@ void CodeDocument::setAttributesFromNode (QDomElement & root)
  * @param doc   the xmi document
  * @param root  the starting point to append
  */
-void CodeDocument::saveToXMI (QDomDocument & doc, QDomElement & root)
+void CodeDocument::saveToXMI1 (QDomDocument & doc, QDomElement & root)
 {
     QDomElement docElement = doc.createElement(QLatin1String("codedocument"));
     setAttributesOnNode(doc, docElement);
@@ -510,17 +510,17 @@ TextBlock * CodeDocument::findTextBlockByTag(const QString &tag, bool descendInt
         if (m_childTextBlockTagMap.contains(tag))
             return m_childTextBlockTagMap[tag];
 
-    return NULL;
+    return 0;
 }
 
 /**
  * Have to implement this for CodeObjectWithTextBlocks.
- * Actually does not do anythying for a vannilla code document.
+ * Actually does not do anything for a vanilla code document.
  */
 TextBlock * CodeDocument::findCodeClassFieldTextBlockByTag (const QString &tag)
 {
     uWarning() << "Called findCodeClassFieldMethodByTag(" << tag << ") for a regular CodeDocument";
-    return NULL;
+    return 0;
 }
 
 QDebug operator<<(QDebug os, const CodeDocument& obj)
