@@ -6,7 +6,7 @@
  *                                                                         *
  *   copyright (C) 2002       Luis De la Parra Blum <luis@delaparra.org>   *
                               Brian Thomas <thomas@mail630.gsfc.nasa.gov>  *
- *   copyright (C) 2003-2014                                               *
+ *   copyright (C) 2003-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -108,7 +108,6 @@ CodeGenerator* createObject(Uml::ProgrammingLanguage::Enum pl)
         case Uml::ProgrammingLanguage::Cpp:
             if (optionState.generalState.newcodegen) {
                 obj = new CPPCodeGenerator();
-                obj->connect_newcodegen_slots();
             } else {
                 obj = new CppWriter();
             }
@@ -119,7 +118,6 @@ CodeGenerator* createObject(Uml::ProgrammingLanguage::Enum pl)
         case Uml::ProgrammingLanguage::D:
             if (optionState.generalState.newcodegen) {
                 obj = new DCodeGenerator();
-                obj->connect_newcodegen_slots();
             } else {
                 obj = new DWriter();
             }
@@ -130,7 +128,6 @@ CodeGenerator* createObject(Uml::ProgrammingLanguage::Enum pl)
         case Uml::ProgrammingLanguage::Java:
             if (optionState.generalState.newcodegen) {
                 obj = new JavaCodeGenerator();
-                obj->connect_newcodegen_slots();
             } else {
                 obj = new JavaWriter();
             }
@@ -162,7 +159,6 @@ CodeGenerator* createObject(Uml::ProgrammingLanguage::Enum pl)
         case Uml::ProgrammingLanguage::Ruby:
             if (optionState.generalState.newcodegen) {
                 obj = new RubyCodeGenerator();
-                obj->connect_newcodegen_slots();
             } else {
                 obj = new RubyWriter();
             }
@@ -197,9 +193,9 @@ CodeDocument * newClassifierCodeDocument(UMLClassifier * c)
 {
     Settings::OptionState optionState = Settings::optionState();
     if (!optionState.generalState.newcodegen) {
-        return NULL;
+        return 0;
     }
-    ClassifierCodeDocument *retval = NULL;
+    ClassifierCodeDocument *retval = 0;
     switch (UMLApp::app()->activeLanguage()) {
         case Uml::ProgrammingLanguage::Cpp:
             retval = new CPPSourceCodeDocument(c);
@@ -216,14 +212,16 @@ CodeDocument * newClassifierCodeDocument(UMLClassifier * c)
         default:
             break;
     }
-    retval->initCodeClassFields();
-    retval->synchronize();
+    if (retval) {
+        retval->initCodeClassFields();
+        retval->synchronize();
+    }
     return retval;
 }
 
 CodeOperation *newCodeOperation(ClassifierCodeDocument *ccd, UMLOperation * op)
 {
-    CodeOperation *retval = NULL;
+    CodeOperation *retval = 0;
     switch (UMLApp::app()->activeLanguage()) {
         case Uml::ProgrammingLanguage::Cpp:
             {
@@ -266,7 +264,7 @@ CodeOperation *newCodeOperation(ClassifierCodeDocument *ccd, UMLOperation * op)
 
 CodeClassField * newCodeClassField(ClassifierCodeDocument *ccd, UMLAttribute *at)
 {
-    CodeClassField *retval = NULL;
+    CodeClassField *retval = 0;
     switch (UMLApp::app()->activeLanguage()) {
         case Uml::ProgrammingLanguage::Cpp:
             retval = new CPPCodeClassField(ccd, at);
@@ -283,13 +281,14 @@ CodeClassField * newCodeClassField(ClassifierCodeDocument *ccd, UMLAttribute *at
         default:
             break;
     }
-    retval->finishInitialization();
+    if (retval)
+        retval->finishInitialization();
     return retval;
 }
 
 CodeClassField * newCodeClassField(ClassifierCodeDocument *ccd, UMLRole *role)
 {
-    CodeClassField *retval = NULL;
+    CodeClassField *retval = 0;
     switch (UMLApp::app()->activeLanguage()) {
         case Uml::ProgrammingLanguage::Cpp:
             retval = new CPPCodeClassField(ccd, role);
@@ -306,7 +305,8 @@ CodeClassField * newCodeClassField(ClassifierCodeDocument *ccd, UMLRole *role)
         default:
             break;
     }
-    retval->finishInitialization();
+    if (retval)
+        retval->finishInitialization();
     return retval;
 }
 
@@ -314,7 +314,7 @@ CodeAccessorMethod * newCodeAccessorMethod(ClassifierCodeDocument *ccd,
                                            CodeClassField *cf,
                                            CodeAccessorMethod::AccessorType type)
 {
-    CodeAccessorMethod *retval = NULL;
+    CodeAccessorMethod *retval = 0;
     switch (UMLApp::app()->activeLanguage()) {
         case Uml::ProgrammingLanguage::Cpp:
             {
@@ -363,7 +363,7 @@ CodeAccessorMethod * newCodeAccessorMethod(ClassifierCodeDocument *ccd,
 CodeClassFieldDeclarationBlock * newDeclarationCodeBlock(ClassifierCodeDocument *cd,
                                                          CodeClassField * cf)
 {
-    CodeClassFieldDeclarationBlock *retval = NULL;
+    CodeClassFieldDeclarationBlock *retval = 0;
     switch (UMLApp::app()->activeLanguage()) {
         case Uml::ProgrammingLanguage::Cpp:
             {
@@ -452,11 +452,11 @@ CodeGenPolicyExt* newCodeGenPolicyExt(Uml::ProgrammingLanguage::Enum pl)
               return new RubyCodeGenerationPolicy();
               break;
           default:
-              return NULL;
+              return 0;
         }
     }
 
-    return NULL;
+    return 0;
 }
 
 }  // end namespace CodeGenFactory
