@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2006-2014                                               *
+ *   copyright (C) 2006-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -14,7 +14,6 @@
 #include <QObject>
 
 class QWidget;
-class KConfig;
 class CodeGenerationPolicyPage;
 
 /**
@@ -23,7 +22,7 @@ class CodeGenerationPolicyPage;
  * language independent policies.
  *
  * @author Oliver Kellogg <okellogg@users.sourceforge.net>
- * Bugs and comments to umbrello-devel@kde.org or http://bugs.kde.org
+ * Bugs and comments to umbrello-devel@kde.org or https://bugs.kde.org
  */
 class CodeGenPolicyExt : public QObject
 {
