@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2003      Brian Thomas <thomas@mail630.gsfc.nasa.gov>   *
- *   copyright (C) 2004-2014                                               *
+ *   copyright (C) 2004-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -14,7 +14,7 @@
 
 #include "codedocumentlist.h"
 #include "codeviewerstate.h"
-#include "codegenerator.h"
+#include "advancedcodegenerator.h"
 #include "cppmakecodedocument.h"
 #include "umldoc.h"
 
@@ -23,7 +23,7 @@
 class CodeViewerDialog;
 class CPPHeaderCodeDocument;
 
-class CPPCodeGenerator : public CodeGenerator
+class CPPCodeGenerator : public AdvancedCodeGenerator
 {
     Q_OBJECT
 public:
@@ -54,7 +54,7 @@ public:
 
     QStringList defaultDatatypes();
 
-    virtual void saveToXMI (QDomDocument & doc, QDomElement & root);
+    virtual void saveToXMI1 (QDomDocument & doc, QDomElement & root);
 
     virtual QStringList reservedKeywords() const;
 
