@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2007 Jari-Matti Mäkelä <jmjm@iki.fi>                    *
- *   copyright (C) 2008                                                    *
+ *   copyright (C) 2008-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -29,7 +29,7 @@ public:
     /**
      * Constructors
      */
-    explicit DCodeComment (CodeDocument * doc, const QString & text = "");
+    explicit DCodeComment (CodeDocument * doc, const QString & text = QString());
 
     /**
      * Empty Destructor
@@ -39,7 +39,7 @@ public:
     /**
      * Save the XMI representation of this object.
      */
-    virtual void saveToXMI (QDomDocument & doc, QDomElement & root);
+    virtual void saveToXMI1 (QDomDocument & doc, QDomElement & root);
 
     /**
      * Creates a comment block.
@@ -53,9 +53,9 @@ public:
 
     /**
      * UnFormat a long text string. Typically, this means removing
-     * the indentaion (linePrefix) and/or newline chars from each line.
+     * the indentation (linePrefix) and/or newline chars from each line.
      */
-    virtual QString unformatText (const QString & text, const QString & indent = "");
+    virtual QString unformatText (const QString & text, const QString & indent = QString());
 
     /**
      * A special version here because we want to not only indent
