@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2007 Jari-Matti Mäkelä <jmjm@iki.fi>                    *
- *   copyright (C) 2008-2014                                               *
+ *   copyright (C) 2008-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -16,7 +16,7 @@
 #include "uml.h"
 
 // kde includes
-#include <klocale.h>
+#include <KLocalizedString>
 
 DCodeGenerationPolicyPage::DCodeGenerationPolicyPage(QWidget *parent, const char *name, DCodeGenerationPolicy * policy)
   : CodeGenerationPolicyPage(parent, name, policy)
@@ -71,4 +71,3 @@ void DCodeGenerationPolicyPage::apply()
     commonPolicy->emitModifiedCodeContentSig();
 }
 
-#include "dcodegenerationpolicypage.moc"
