@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2007 Jari-Matti Mäkelä <jmjm@iki.fi>                    *
- *   copyright (C) 2008-2014                                               *
+ *   copyright (C) 2008-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -29,10 +29,11 @@
  * Constructor.
  */
 DCodeGenerator::DCodeGenerator()
-  : CodeGenerator()
+  : AdvancedCodeGenerator()
 {
     // load Classifier documents from parent document
     //initFromParentDocument();
+    connectSlots();
 }
 
 /**
@@ -113,7 +114,7 @@ QString DCodeGenerator::capitalizeFirstLetter(const QString &item)
 
 /**
  * IF the type is "string" we need to declare it as
- * the D Object "String" (there is no string primative in D).
+ * the D Object "String" (there is no string primitive in D).
  * Same thing again for "bool" to "boolean".
  * @param item   the item to change
  * @return the changed item
@@ -169,7 +170,8 @@ QStringList DCodeGenerator::defaultDatatypes()
       << QLatin1String("creal")
       << QLatin1String("char")
       << QLatin1String("wchar")
-      << QLatin1String("dchar");
+      << QLatin1String("dchar")
+      << QLatin1String("string");
     return l;
 }
 
