@@ -6,7 +6,7 @@
  *                                                                         *
  *   copyright (C) 2005                                                    *
  *   Richard Dale  <Richard_Dale@tipitina.demon.co.uk>                     *
- *   copyright (C) 2006-2014                                               *
+ *   copyright (C) 2006-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -27,7 +27,7 @@ public:
     /**
      * Empty Constructor
      */
-    RubyCodeOperation (RubyClassifierCodeDocument * doc, UMLOperation * op, const QString & body = "", const QString & comment = "");
+    RubyCodeOperation (RubyClassifierCodeDocument * doc, UMLOperation * op, const QString & body = QString(), const QString & comment = QString());
 
     /**
      * Empty Destructor
