@@ -6,7 +6,7 @@
  *                                                                         *
  *   copyright (C) 2005                                                    *
  *   Richard Dale  <Richard_Dale@tipitina.demon.co.uk>                     *
- *   copyright (C) 2006-2014                                               *
+ *   copyright (C) 2006-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -20,8 +20,8 @@
 #include "umldoc.h"
 #include "umlattributelist.h"
 
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <KLocalizedString>
+#include <KMessageBox>
 
 #include <QFile>
 #include <QRegExp>
@@ -70,7 +70,7 @@ void RubyWriter::writeClass(UMLClassifier *c)
     //Start generating the code!!
     /////////////////////////////
 
-    //try to find a heading file (license, coments, etc)
+    //try to find a heading file (license, comments, etc)
     QString str;
 
     str = getHeadingFile(QLatin1String(".rb"));
@@ -478,4 +478,3 @@ QStringList RubyWriter::reservedKeywords() const
     return keywords;
 }
 
-#include "rubywriter.moc"
