@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2003      Brian Thomas <thomas@mail630.gsfc.nasa.gov>   *
- *   copyright (C) 2004-2014                                               *
+ *   copyright (C) 2004-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -26,12 +26,14 @@
 #include "uml.h"
 
 // kde includes
-#include <klocale.h>
-#include <kmessagebox.h>
+#if QT_VERSION < 0x050000
 #include <kdialog.h>
-#include <kapplication.h>
+#endif
+#include <KLocalizedString>
+#include <KMessageBox>
 
 // qt includes
+#include <QApplication>
 #include <QDateTime>
 #include <QDir>
 #include <QPointer>
@@ -175,20 +177,28 @@ QString SimpleCodeGenerator::overwritableName(UMLPackage* concept, const QString
     int suffix;
     QPointer<OverwriteDialog> overwriteDialog =
         new OverwriteDialog(filename, outputDir.absolutePath(),
-                              m_applyToAllRemaining, kapp->activeWindow());
+                              m_applyToAllRemaining, qApp->activeWindow());
     switch(commonPolicy->getOverwritePolicy()) {  //if it exists, check the OverwritePolicy we should use
     case CodeGenerationPolicy::Ok:                //ok to overwrite file
         break;
     case CodeGenerationPolicy::Ask:               //ask if we can overwrite
         switch(overwriteDialog->exec()) {
-        case QDialog::Accepted:  //overwrite file
+#if QT_VERSION >= 0x050000
+        case OverwriteDialog::Ok:  //overwrite file
+#else
+        case QDialog::Accepted:
+#endif
             if (overwriteDialog->applyToAllRemaining()) {
                 commonPolicy->setOverwritePolicy(CodeGenerationPolicy::Ok);
             } else {
                 m_applyToAllRemaining = false;
             }
             break;
-        case KDialog::No: //generate similar name
+#if QT_VERSION >= 0x050000
+        case OverwriteDialog::No: //generate similar name
+#else
+        case KDialog::No:
+#endif
             suffix = 1;
             while (1) {
                 filename = name + QLatin1String("__") + QString::number(suffix) + ext;
@@ -202,7 +212,11 @@ QString SimpleCodeGenerator::overwritableName(UMLPackage* concept, const QString
                 m_applyToAllRemaining = false;
             }
             break;
-        case QDialog::Rejected: //don't output anything
+#if QT_VERSION >= 0x050000
+        case OverwriteDialog::Cancel: //don't output anything
+#else
+        case QDialog::Rejected:
+#endif
             if (overwriteDialog->applyToAllRemaining()) {
                 commonPolicy->setOverwritePolicy(CodeGenerationPolicy::Cancel);
             } else {
@@ -263,18 +277,6 @@ bool SimpleCodeGenerator::hasAbstractOps(UMLClassifier *c)
     return false;
 }
 
-/**
- * Create a new classifier code document.
- * TODO: Not yet implemented.
- * @param classifier   UML classifier
- * @return classifier code document object
- */
-CodeDocument * SimpleCodeGenerator::newClassifierCodeDocument(UMLClassifier* classifier)
-{
-    Q_UNUSED(classifier);
-    return 0;
-}
-
 /**
  * Write all concepts in project to file.
  */
@@ -318,4 +320,3 @@ void SimpleCodeGenerator::initFromParentDocument()
     // do nothing
 }
 
-#include "simplecodegenerator.moc"
