@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2003      Nikolaus Gradwohl  <guru@local-guru.net>      *
- *   copyright (C) 2004-2014                                               *
+ *   copyright (C) 2004-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -216,7 +216,7 @@ void SQLWriter::writeClass(UMLClassifier *c)
     //Start generating the code!!
 
     QTextStream sql(&file);
-    //try to find a heading file (license, coments, etc)
+    //try to find a heading file (license, comments, etc)
     QString str;
     str = getHeadingFile(QLatin1String(".sql"));
     if (!str.isEmpty()) {
@@ -225,7 +225,7 @@ void SQLWriter::writeClass(UMLClassifier *c)
         sql << str << m_endl;
     }
 
-    //Write class Documentation if there is somthing or if force option
+    //Write class Documentation if there is something or if force option
     if (forceDoc() || !m_pEntity->doc().isEmpty()) {
         sql << m_endl << "--" << m_endl;
         sql << "-- TABLE: " << entityname << m_endl;
@@ -406,7 +406,8 @@ void SQLWriter::printEntityAttributes(QTextStream& sql, UMLEntityAttributeList e
         sql << m_indentation << cleanName(at->name()) ;
 
         // the datatype
-        if (language() == Uml::ProgrammingLanguage::MySQL && at->getType()->baseType() == UMLObject::ot_Enum) {
+        if (language() == Uml::ProgrammingLanguage::MySQL &&
+                at->getType() && at->getType()->baseType() == UMLObject::ot_Enum) {
             UMLEnum *_enum = at->getType()->asUMLEnum();
             sql << " ENUM(";
             QString delimiter(QLatin1String(""));
@@ -595,7 +596,7 @@ void SQLWriter::printIndex(QTextStream& sql, UMLEntity* ent, UMLEntityAttributeL
     }
     sql << "index ";
 
-    sql << " ON " << cleanName(m_pEntity->name()) << '(';
+    sql << " ON " << cleanName(ent->name()) << '(';
 
     bool first = true;
 
