@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2003      Brian Thomas <thomas@mail630.gsfc.nasa.gov>   *
- *   copyright (C) 2004-2014                                               *
+ *   copyright (C) 2004-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -19,7 +19,7 @@
 class CodeDocument;
 
 /**
- * The fundemental unit of text within an output file containing code.
+ * The fundamental unit of text within an output file containing code.
  */
 class TextBlock
 {
@@ -27,7 +27,7 @@ class TextBlock
     friend class ClassifierCodeDocument;
 public:
 
-    explicit TextBlock(CodeDocument * parent, const QString & text = "");
+    explicit TextBlock(CodeDocument * parent, const QString & text = QString());
     virtual ~TextBlock();
 
     void setText(const QString & text);
@@ -55,7 +55,7 @@ public:
                                   const QString & breakStr,
                                   bool addBreak = true, bool lastLineHasBreak = true);
 
-    virtual QString unformatText(const QString & text, const QString & indent = "");
+    virtual QString unformatText(const QString & text, const QString & indent = QString());
 
     virtual QString toString() const;
 
@@ -67,13 +67,13 @@ public:
      * @param doc    the xmi document
      * @param root   the starting point to append
      */
-    virtual void saveToXMI(QDomDocument & doc, QDomElement & root) = 0;
+    virtual void saveToXMI1(QDomDocument & doc, QDomElement & root) = 0;
 
     /**
      * Load params from the appropriate XMI element node.
      * @param root   the starting point in the xmi document to load from
      */
-    virtual void loadFromXMI(QDomElement & root) = 0;
+    virtual void loadFromXMI1(QDomElement & root) = 0;
 
     bool canDelete() const;
 
