@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2003      Brian Thomas <thomas@mail630.gsfc.nasa.gov>   *
- *   copyright (C) 2004-2014                                               *
+ *   copyright (C) 2004-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -22,7 +22,7 @@ XMLCodeComment::~XMLCodeComment ()
 
 QString XMLCodeComment::toString () const
 {
-    QString output = "";
+    QString output;
 
     // simple output method
     if (getWriteOutText())
@@ -30,11 +30,11 @@ QString XMLCodeComment::toString () const
         QString indent = getIndentationString();
         QString endLine = getNewLineEndingChars();
         QString body = getText();
-        output.append(indent+"<!-- ");
+        output.append(indent + QLatin1String("<!-- "));
         if (!body.isEmpty()) {
             output.append(formatMultiLineText (body, indent, endLine));
         }
-        output.append(indent+"-->"+endLine);
+        output.append(indent + QLatin1String("-->") + endLine);
     }
 
     return output;
