@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2003      Brian Thomas <thomas@mail630.gsfc.nasa.gov>   *
- *   copyright (C) 2004-2014                                               *
+ *   copyright (C) 2004-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -29,7 +29,7 @@ public:
     /**
      * Constructors
      */
-    explicit XMLCodeComment (CodeDocument * doc, const QString & text = "");
+    explicit XMLCodeComment (CodeDocument * doc, const QString & text = QString());
 
     /**
      * Empty Destructor
