@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2003      Brian Thomas <brian.thomas@gsfc.nasa.gov>     *
- *   copyright (C) 2004-2014                                               *
+ *   copyright (C) 2004-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -30,7 +30,7 @@
   * Our basic approach is to map UMLClassifiers (classes/interfaces) into
   * XML elements (or nodes). We declare these element in the schema either
   * as complexType or as groups based on whether they are concrete or abstract
-  * in nature. This is not a perfect decision, but thats life with XML Schema...
+  * in nature. This is not a perfect decision, but that's life with XML Schema...
   * you cant fully represent Objects in the XML world ..yet. -b.t.
   */
 
@@ -74,27 +74,27 @@ private:
      */
 //    void writeAttributes(UMLClassifier *c, QTextStream &j);
 
-    void writeElementDecl(const QString &elementName, const QString &elementTypeName, QTextStream &XMLschema);
+    void writeElementDecl(const QString &elementName, const QString &elementTypeName, QTextStream &xs);
 
-    void writeAttributeDecls(UMLAttributeList &attribs, QTextStream &XMLschema);
+    void writeAttributeDecls(UMLAttributeList &attribs, QTextStream &xs);
 
-    void writeAttributeDecl(UMLAttribute *attrib, QTextStream &XMLschema);
+    void writeAttributeDecl(UMLAttribute *attrib, QTextStream &xs);
 
     UMLAttributeList findAttributes(UMLClassifier *c);
 
     QStringList findAttributeGroups(UMLClassifier *c);
 
     bool writeAssociationDecls(UMLAssociationList associations, bool noRoleOK, bool didOne,
-                               Uml::ID::Type id, QTextStream &XMLschema);
+                               Uml::ID::Type id, QTextStream &xs);
 
-    void writeAttributeGroupDecl(const QString &elementName, UMLAttributeList &attribs, QTextStream &XMLschema);
+    void writeAttributeGroupDecl(const QString &elementName, UMLAttributeList &attribs, QTextStream &xs);
 
-    void writeAssociationRoleDecl(UMLClassifier *c, const QString &multi, QTextStream &XMLschema);
+    void writeAssociationRoleDecl(UMLClassifier *c, const QString &multi, QTextStream &xs);
 
     QString makeSchemaTag(QString tagName);
     QString makePackageTag(QString tagName);
 
-    void writeComment(const QString &text, QTextStream &XMLschema);
+    void writeComment(const QString &text, QTextStream &xs);
 
     UMLObjectList findChildObjsInAssociations(UMLClassifier *c, UMLAssociationList associations);
 
