@@ -19,6 +19,7 @@
 // fwd decls
 class CodeImpThread;
 class UMLClassifier;
+class UMLFolder;
 class UMLOperation;
 class UMLPackage;
 
@@ -28,6 +29,8 @@ public:
     explicit CppTree2Uml(const QString& fileName, CodeImpThread* thread = 0);
     virtual ~CppTree2Uml();
 
+    void clear();
+    void setRootPath(const QString &rootPath);
     //FileDom file() { return m_file; }
 
     // translation-unit
@@ -88,6 +91,9 @@ private:
     int m_nsCnt;  ///< stack top for m_currentNamespace
     int m_clsCnt;  ///< stack top for m_currentClass
     CodeImpThread* m_thread;
+    QString m_rootPath; ///< root path of project
+    UMLFolder *m_rootFolder;
+    UMLDoc *m_doc;
 
 private:
     CppTree2Uml(const CppTree2Uml& source);
