@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *  copyright (C) 2005-2014                                                *
+ *  copyright (C) 2005-2020                                                *
  *  Umbrello UML Modeller Authors <umbrello-devel@kde.org>                 *
  ***************************************************************************/
 
@@ -39,7 +39,7 @@ class UMLClassifier;
  *
  * @short Base class for native implementations of language import
  * @author Oliver Kellogg <okellogg@users.sourceforge.net>
- * Bugs and comments to umbrello-devel@kde.org or http://bugs.kde.org
+ * Bugs and comments to umbrello-devel@kde.org or https://bugs.kde.org
  */
 class NativeImportBase : public ClassImport
 {
@@ -83,6 +83,7 @@ protected:
     void skipStmt(const QString& until = QLatin1String(";"));
     bool skipToClosing(QChar opener);
 
+    QString lookAhead();
     virtual QString advance();
 
     void pushScope(UMLPackage *p);
