@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *  copyright (C) 2017                                                     *
+ *  copyright (C) 2017-2020                                                *
  *  Umbrello UML Modeller Authors <umbrello-devel@kde.org>                 *
  ***************************************************************************/
 
@@ -39,18 +39,21 @@ QTextStream qout(stdout);
 QTextStream qerr(stderr);
 QTextStream qin(stdin);
 
-#include "parsesession.h"
-#include "phplexer.h"
-#include "phpparser.h"
-#include "phpdebugvisitor.h"
-#include "phpast.h"
-#include "tokenstream.h"
-#include "phptokentext.h"
+// kdevphp
+#include <parser/parsesession.h>
+#include <parser/phplexer.h>
+#include <parser/phpparser.h>
+#include <parser/phpdebugvisitor.h>
+#include <parser/phpast.h>
+#include <parser/tokenstream.h>
+#include <parser/phptokentext.h>
 
+// kdevplatform
 #include <tests/autotestshell.h>
 #include <language/duchain/duchain.h>
 #include <language/duchain/problem.h>
 #include <language/codegen/coderepresentation.h>
+#include <language/editor/documentrange.h>
 #include <tests/testcore.h>
 
 namespace Php {
@@ -633,8 +636,14 @@ private:
             qout << endl << "problems encountered during parsing:" << endl;
             foreach(KDevelop::ProblemPointer p, m_session.problems()) {
                 QString item = QString::fromLatin1("%1:%2:%3: %4: %5")
+#if QT_VERSION > 0x050000
+                        .arg(fileName).arg(p->finalLocation().start().line()+1)
+                        .arg(p->finalLocation().start().column())
+#else
                         .arg(fileName).arg(p->finalLocation().start.line+1)
-                        .arg(p->finalLocation().start.column).arg(p->severityString()).arg(p->description());
+                        .arg(p->finalLocation().start.column)
+#endif
+                        .arg(p->severityString()).arg(p->description());
                 UMLApp::app()->logWindow()->addItem(item);
             }
         } else {
