@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2003-2014                                               *
+ *   copyright (C) 2003-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -17,7 +17,6 @@
 #include "umlobject.h"
 
 class CodeTextEdit;
-class ListPopupMenu;
 class UMLClassifier;
 class UMLDoc;
 class KTextEdit;
@@ -35,7 +34,7 @@ class QVBoxLayout;
  *
  * @short A dialog page to display classifier properties.
  * @author Paul Hensgen, Jonathan Riddell
- * Bugs and comments to umbrello-devel@kde.org or http://bugs.kde.org
+ * Bugs and comments to umbrello-devel@kde.org or https://bugs.kde.org
  */
 class ClassifierListPage : public DialogPageBase
 {
@@ -84,7 +83,6 @@ private:
     QToolButton*   m_pBottomArrowB;
 
     UMLDoc*        m_doc;
-    ListPopupMenu* m_pMenu;
     UMLClassifierListItem* m_pOldListItem;
 
 protected:
