@@ -4,9 +4,9 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002                                                    *
+ *   copyright (C) 2002-2020                                               *
  *   Luis De la Parra <luis@delaparra.org>                                 *
- *   copyright (C) 2003-2014                                               *
+ *   copyright (C) 2003-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 #ifndef CODEVIEWEROPTIONSPAGE_H
@@ -23,7 +23,7 @@ class CodeViewerOptionsPage : public DialogPageBase, private Ui::CodeViewerOptio
 {
     Q_OBJECT
 public:
-    CodeViewerOptionsPage (Settings::CodeViewerState options, QWidget *parent, const char *name = 0);
+    explicit CodeViewerOptionsPage (Settings::CodeViewerState options, QWidget *parent = 0, const char *name = 0);
     ~CodeViewerOptionsPage();
 
     Settings::CodeViewerState getOptions();
