@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2014                                               *
+ *   copyright (C) 2002-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -15,10 +15,7 @@
 
 #include <QWidget>
 
-/**
- * @author Paul Hensgen
- * Bugs and comments to umbrello-devel@kde.org or http://bugs.kde.org
- */
+class SelectLayoutTypeWidget;
 class UMLScene;
 class WidgetBase;
 class KColorButton;
@@ -33,6 +30,10 @@ class QGroupBox;
 class QSpinBox;
 #endif
 
+/**
+ * @author Paul Hensgen
+ * Bugs and comments to umbrello-devel@kde.org or https://bugs.kde.org
+ */
 class UMLWidgetStylePage : public QWidget
 {
     Q_OBJECT
@@ -83,6 +84,8 @@ protected:
     KColorButton * m_pFillColorB;
     KColorButton * m_BackgroundColorB;
     KColorButton * m_GridDotColorB;
+    SelectLayoutTypeWidget *m_layoutTypeW;
+
 #if QT_VERSION >= 0x050000
     QSpinBox * m_lineWidthB;
 #else
