@@ -4,44 +4,51 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *  copyright (C) 2002-2014                                                *
+ *  copyright (C) 2002-2020                                                *
  *  Umbrello UML Modeller Authors <umbrello-devel@kde.org>                 *
  ***************************************************************************/
 #ifndef SETTINGSDIALOG_H
 #define SETTINGSDIALOG_H
 
 // app includes
-#include "dialogbase.h"
+#include "multipagedialogbase.h"
 #include "optionstate.h"
 
 // kde includes
 #include <kcombobox.h>
-#include <kfontdialog.h>
 #include <kcolorbutton.h>
-#include <knuminput.h>
 #include <klineedit.h>
 
-// qt includes
-#include <QCheckBox>
-#include <QGroupBox>
-#include <QLabel>
-#include <QPushButton>
-#include <QRadioButton>
-
-class UMLWidgetStylePage;
 class AutoLayoutOptionPage;
 class ClassOptionsPage;
 class CodeImportOptionsPage;
 class CodeGenOptionsPage;
 class CodeViewerOptionsPage;
+class DontAskAgainWidget;
 class GeneralOptionPage;
+class KColorButton;
+class KFontChooser;
+#if QT_VERSION < 0x050000
+class KIntSpinBox;
+#endif
+class UIOptionsPage;
+
+class QCheckBox;
+#if QT_VERSION >= 0x050000
+class QFontDialog;
+#endif
+class QGroupBox;
+#if QT_VERSION >= 0x050000
+class QSpinBox;
+#endif
+class UMLWidgetStylePage;
 
 /**
  * @author Paul Hensgen
  * modified by brian thomas Aug-2003
- * Bugs and comments to umbrello-devel@kde.org or http://bugs.kde.org
+ * Bugs and comments to umbrello-devel@kde.org or https://bugs.kde.org
  */
-class SettingsDialog : public DialogBase
+class SettingsDialog : public MultiPageDialogBase
 {
     Q_OBJECT
 
@@ -49,6 +56,8 @@ public:
     SettingsDialog(QWidget * parent, Settings::OptionState *state);
     ~SettingsDialog();
 
+    void setCurrentPage(PageType page);
+
     //public methods
     bool getChangesApplied() {
         return m_bChangesApplied;
@@ -61,6 +70,7 @@ protected:
 private:
     //private structs
     struct UIWidgets {
+        QCheckBox * rightToLeftUI;
         QGroupBox * colorGB;
 
         QCheckBox * textColorCB;
@@ -75,18 +85,16 @@ private:
         KColorButton * fillColorB;
         KColorButton * gridColorB;
         KColorButton * bgColorB;
+#if QT_VERSION >= 0x050000
+        QSpinBox     * lineWidthB;
+#else
         KIntSpinBox  * lineWidthB;
-
+#endif
         QCheckBox * useFillColorCB;
     }
     ;//end struct UIWidgets
 
-    struct FontWidgets {
-        KFontChooser * chooser;
-    };
-
     //private methods
-    void setupFontPage();
     void setupUIPage();
     void setupGeneralPage();
     void setupClassPage();
@@ -97,8 +105,7 @@ private:
     void applyPage(KPageWidgetItem*);
 
     //private attributes
-    FontWidgets m_FontWidgets;
-    UIWidgets m_UiWidgets;
+    DontAskAgainWidget *m_dontAskAgainWidget;
     Settings::OptionState *m_pOptionState;
     UMLWidgetStylePage * m_pUserInterfacePage;
     AutoLayoutOptionPage * m_pAutoLayoutPage;
@@ -107,6 +114,7 @@ private:
     CodeViewerOptionsPage * m_pCodeViewerPage;
     GeneralOptionPage * m_pGeneralPage;
     ClassOptionsPage * m_pClassPage;
+    UIOptionsPage *m_uiOptionsPage;
 
     bool m_bChangesApplied;
     KPageWidgetItem *pageCodeViewer, *pageFont, *pageCodeImport, *pageCodeGen,
@@ -116,12 +124,6 @@ private slots:
     void slotApply();
     void slotOk();
     void slotDefault();
-    void slotTextCBChecked(bool value);
-    void slotLineCBChecked(bool value);
-    void slotFillCBChecked(bool value);
-    void slotGridCBChecked(bool value);
-    void slotBgCBChecked(bool value);
-    void slotLineWidthCBChecked(bool value);
 };
 
 #endif
