@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2014                                               *
+ *   copyright (C) 2002-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -15,6 +15,7 @@
 
 class AssociationWidget;
 class KTextEdit;
+class ModifiedWidget;
 class QLabel;
 class UMLObject;
 class UMLDoc;
@@ -23,7 +24,7 @@ class UMLWidget;
 
 /**
  * @author Paul Hensgen
- * Bugs and comments to umbrello-devel@kde.org or http://bugs.kde.org
+ * Bugs and comments to umbrello-devel@kde.org or https://bugs.kde.org
  */
 class DocWindow : public QWidget
 {
@@ -50,6 +51,7 @@ public slots:
 
 private slots:
     void slotTextChanged();
+    void slotFocusEnabledChanged(int state);
 
 private:
     /**
@@ -74,12 +76,14 @@ private:
 
     QLabel    *m_typeLabel;      ///< label for type icon
     QLabel    *m_nameLabel;      ///< label for name text
-    QLabel    *m_modifiedLabel;  ///< label for modified flag icon
+    ModifiedWidget *m_modifiedWidget;  ///< label for modified flag icon
     KTextEdit *m_docTE;          ///< documentation widget
+    bool m_focusEnabled;
 
     bool isModified();
     QLabel* createPixmapLabel();
     void updateLabel(const QString &name = QString());
+    void toForeground();
 };
 
 #endif
