@@ -1,6 +1,6 @@
 /*
     Copyright 2008  Andreas Fischer  <andi.fischer@hispeed.ch>
-    Copyright (C) 2009-2014                                               *
+    Copyright (C) 2009-2020                                               *
     Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
 
     This program is free software; you can redistribute it and/or
@@ -315,6 +315,8 @@ QString toString(IconType type)
     case it_Literal_New: return QLatin1String("text-x-generic");
     case it_Message_Async: return QLatin1String("umbr-message-asynchronous");
     case it_Message_Asynchronous: return QLatin1String("umbr-coll-message-asynchronous");
+    case it_Message_Creation: return QLatin1String("umbr-message-creation");
+    case it_Message_Destroy: return QLatin1String("umbr-message-destroy");
     case it_Message_Found: return QLatin1String("umbr-message-found");
     case it_Message_Lost: return QLatin1String("umbr-message-lost");
     case it_Message_Sync: return QLatin1String("umbr-message-synchronous");
