@@ -4,14 +4,14 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2006-2014                                               *
+ *   copyright (C) 2006-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
 #ifndef IMPORT_ARGO_H
 #define IMPORT_ARGO_H
 
-#include <qiodevice.h>
+#include <QIODevice>
 
 class UMLPackage;
 class KZip;
@@ -20,7 +20,7 @@ class KZip;
  * Argo model import
  *
  * @author Ralf Habacker
- * Bugs and comments to umbrello-devel@kde.org or http://bugs.kde.org
+ * Bugs and comments to umbrello-devel@kde.org or https://bugs.kde.org
  */
 class Import_Argo
 {
