@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2004-2014                                               *
+ *   copyright (C) 2004-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -16,7 +16,9 @@
 #include "association.h"
 #include "associationline.h"
 #include "associationwidget.h"
+#include "classifier.h"
 #include "classifierwidget.h"
+#include "cmds/widget/cmdcreatewidget.h"
 #include "floatingtextwidget.h"
 #include "debug_utils.h"
 #include "folder.h"
@@ -189,6 +191,7 @@ void ToolBarStateAssociation::setFirstWidget()
     cleanAssociation();
     m_firstWidget = widget;
 
+    // preliminary line
     m_associationLine = new QGraphicsLineItem();
     m_pUMLScene->addItem(m_associationLine);
     m_associationLine->setLine(pos.x(), pos.y(), pos.x(), pos.y());
@@ -229,20 +232,41 @@ void ToolBarStateAssociation::setSecondWidget()
         valid = AssocRules::allowAssociation(type, widgetA, widgetB);
     }
     if (valid) {
+        if (widgetA->changesShape())
+            widgetA->updateGeometry();
+        if (widgetB->changesShape())
+            widgetB->updateGeometry();
+        if (widgetA->isClassWidget() && widgetB->isClassWidget()) {
+            if (type == Uml::AssociationType::Composition) {
+                UMLClassifier *c = widgetA->umlObject()->asUMLClassifier();
+                UMLAttribute *attr = new UMLAttribute(c, c->uniqChildName(UMLObject::ot_Attribute));
+                attr->setType(widgetB->umlObject());
+                c->addAttribute(attr);
+                cleanAssociation();
+                emit finished();
+                return;
+            }
+            /*  Activating this code will produce a DataType named as the Role B type
+                with a suffixed "*" to indicate it is a pointer type.
+                However, this is a non standard, C++ specific notation.
+                Further, if this code is activated then no Aggregation association to the
+                role B type will be shown. Instead, if the "B*" pointer type is dragged
+                to the diagram then a Composition to that type will be shown.
+            else if (type == Uml::AssociationType::Aggregation) {
+                UMLClassifier *c = widgetA->umlObject()->asUMLClassifier();
+                UMLAttribute *attr = new UMLAttribute(c, c->uniqChildName(UMLObject::ot_Attribute));
+                attr->setTypeName(QString(QLatin1String("%1*")).arg(widgetB->umlObject()->name()));
+                c->addAttribute(attr);
+                cleanAssociation();
+                emit finished();
+                return;
+            } */
+        }
         AssociationWidget *temp = AssociationWidget::create(m_pUMLScene, widgetA, type, widgetB);
         FloatingTextWidget *wt = temp->textWidgetByRole(Uml::TextRole::Coll_Message);
         if (wt)
             wt->showOperationDialog();
-        if (addAssociationInViewAndDoc(temp)) {
-            if (type == Uml::AssociationType::Containment) {
-                UMLObject *newContainer = widgetA->umlObject();
-                UMLObject *objToBeMoved = widgetB->umlObject();
-                if (newContainer && objToBeMoved) {
-                    Model_Utils::treeViewMoveObjectTo(newContainer, objToBeMoved);
-                }
-            }
-            UMLApp::app()->document()->setModified();
-        }
+        UMLApp::app()->executeCommand(new Uml::CmdCreateWidget(temp));
     } else {
         //TODO improve error feedback: tell the user what are the valid type of associations for
         //the second widget using the first widget
@@ -250,6 +274,7 @@ void ToolBarStateAssociation::setSecondWidget()
     }
 
     cleanAssociation();
+    emit finished();
 }
 
 /**
@@ -271,6 +296,8 @@ Uml::AssociationType::Enum ToolBarStateAssociation::getAssociationType()
         case WorkToolBar::tbb_Relationship:             at = Uml::AssociationType::Relationship;      break;
         case WorkToolBar::tbb_Dependency:               at = Uml::AssociationType::Dependency;        break;
         case WorkToolBar::tbb_Containment:              at = Uml::AssociationType::Containment;       break;
+        case WorkToolBar::tbb_Seq_Message_Creation:
+        case WorkToolBar::tbb_Seq_Message_Destroy:
         case WorkToolBar::tbb_Seq_Message_Synchronous:
         case WorkToolBar::tbb_Seq_Combined_Fragment:
         case WorkToolBar::tbb_Seq_Precondition:
