@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2004-2014                                               *
+ *   copyright (C) 2004-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 #include "toolbarstatefactory.h"
@@ -58,7 +58,7 @@ ToolBarState* ToolBarStateFactory::getState(const WorkToolBar::ToolBar_Buttons &
     }
 
     // Make explicit the selected button. This is only necessary for states with a pool.
-    if (key != 3) ((ToolBarStatePool *) m_states[key])->setButton(toolbarButton);
+    if (key != 3) ((ToolBarStatePool*) m_states[key].data())->setButton(toolbarButton);
 
     return m_states[key];
 }
@@ -87,6 +87,8 @@ int ToolBarStateFactory::getKey(const WorkToolBar::ToolBar_Buttons &toolbarButto
     case WorkToolBar::tbb_Child2Category:           return 1;
 
         // Messages
+    case WorkToolBar::tbb_Seq_Message_Creation:     return 2;
+    case WorkToolBar::tbb_Seq_Message_Destroy:      return 2;
     case WorkToolBar::tbb_Seq_Message_Synchronous:  return 2;
     case WorkToolBar::tbb_Seq_Message_Asynchronous: return 2;
     case WorkToolBar::tbb_Seq_Message_Found:        return 2;
@@ -94,6 +96,7 @@ int ToolBarStateFactory::getKey(const WorkToolBar::ToolBar_Buttons &toolbarButto
 
     case WorkToolBar::tbb_Seq_Precondition:         return 4;
     case WorkToolBar::tbb_Pin:                      return 4;
+    case WorkToolBar::tbb_Port:                     return 4;
 
         // Arrow pointer
     case WorkToolBar::tbb_Arrow:                    return 3;
