@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2004-2014                                               *
+ *   copyright (C) 2004-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -12,14 +12,17 @@
 #include "toolbarstatemessages.h"
 
 // local includes
+#include "cmds.h"
 #include "debug_utils.h"
 #include "floatingtextwidget.h"
 #include "messagewidget.h"
 #include "objectwidget.h"
+#include "object_factory.h"
 #include "uml.h"
 #include "umldoc.h"
 #include "umlview.h"
 #include "umlscene.h"
+#include "widget_factory.h"
 
 // kde includes
 #include <KLocalizedString>
@@ -175,7 +178,25 @@ void ToolBarStateMessages::mouseReleaseEmpty()
 {
     Uml::SequenceMessage::Enum msgType = getMessageType();
 
-    if (m_firstObject && msgType ==  Uml::SequenceMessage::Lost) {
+    if (m_firstObject && msgType ==  Uml::SequenceMessage::Creation) {
+        xclick = m_pMouseEvent->scenePos().x();
+        yclick = m_pMouseEvent->scenePos().y();
+
+        bool state = m_pUMLScene->getCreateObject();
+        m_pUMLScene->setCreateObject(false);
+        UMLObject *object = Object_Factory::createUMLObject(UMLObject::ot_Class);
+        m_pUMLScene->setCreateObject(state);
+        ObjectWidget *widget = (ObjectWidget *)Widget_Factory::createWidget(m_pUMLScene, object);
+        widget->setX(xclick);
+        widget->activate();
+        m_pUMLScene->addWidgetCmd(widget);
+
+        MessageWidget* message = new MessageWidget(m_pUMLScene, m_firstObject, widget, yclick, msgType);
+        setupMessageWidget(message, false);
+        cleanMessage();
+        xclick = 0;
+        yclick = 0;
+    } else if (m_firstObject && msgType ==  Uml::SequenceMessage::Lost) {
         xclick = m_pMouseEvent->scenePos().x();
         yclick = m_pMouseEvent->scenePos().y();
 
@@ -260,12 +281,9 @@ void ToolBarStateMessages::setSecondWidget(ObjectWidget* secondObject, MessageTy
         yclick = 0;
         return;
     }
-    //TODO shouldn't start position in the first widget be used also for normal messages
-    //and not only for creation?
-    qreal y = m_pMouseEvent->scenePos().y();
+    qreal y = m_messageLine->line().p1().y();
     if (messageType == CreationMessage) {
         msgType = Uml::SequenceMessage::Creation;
-        y = m_messageLine->line().p1().y();
     }
 
     MessageWidget* message = new MessageWidget(m_pUMLScene, m_firstObject,
@@ -281,7 +299,13 @@ void ToolBarStateMessages::setSecondWidget(ObjectWidget* secondObject, MessageTy
  */
 Uml::SequenceMessage::Enum ToolBarStateMessages::getMessageType()
 {
-    if (getButton() == WorkToolBar::tbb_Seq_Message_Synchronous) {
+    if (getButton() == WorkToolBar::tbb_Seq_Message_Creation) {
+        return Uml::SequenceMessage::Creation;
+    }
+    else if (getButton() == WorkToolBar::tbb_Seq_Message_Destroy) {
+        return Uml::SequenceMessage::Destroy;
+    }
+    else if (getButton() == WorkToolBar::tbb_Seq_Message_Synchronous) {
         return Uml::SequenceMessage::Synchronous;
     }
     else if (getButton() == WorkToolBar::tbb_Seq_Message_Found) {
@@ -305,18 +329,21 @@ void ToolBarStateMessages::cleanMessage()
     m_messageLine = 0;
 }
 
-void ToolBarStateMessages::setupMessageWidget(MessageWidget *message)
+void ToolBarStateMessages::setupMessageWidget(MessageWidget *message, bool showOperationDialog)
 {
-    m_pUMLScene->addWidgetCmd(message);
-    message->activate();
-
-    FloatingTextWidget *ft = message->floatingTextWidget();
-    //TODO cancel doesn't cancel the creation of the message, only cancels setting an operation.
-    //Shouldn't it cancel also the whole creation?
-    ft->showOperationDialog();
-    message->setTextPosition();
-    m_pUMLScene->addWidgetCmd(ft);
-
-    UMLApp::app()->document()->setModified();
+    if (showOperationDialog) {
+        FloatingTextWidget *ft = message->floatingTextWidget();
+        //TODO cancel doesn't cancel the creation of the message, only cancels setting an operation.
+        //Shouldn't it cancel also the whole creation?
+        if (message->sequenceMessageType() == Uml::SequenceMessage::Destroy) {
+            message->setOperationText(i18n("destroy"));
+        } else {
+            ft->showOperationDialog();
+            m_pUMLScene->addWidgetCmd(ft);
+        }
+        message->setTextPosition();
+    }
+    UMLApp::app()->executeCommand(new Uml::CmdCreateWidget(message));
+    emit finished();
 }
 
