@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2014                                               *
+ *   copyright (C) 2002-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -94,7 +94,7 @@ class QSlider;
  * @see KConfig
  *
  * @author Paul Hensgen <phensgen@techie.com>
- * Bugs and comments to umbrello-devel@kde.org or http://bugs.kde.org
+ * Bugs and comments to umbrello-devel@kde.org or https://bugs.kde.org
  */
 class UMLApp : public KXmlGuiWindow
 {
@@ -197,6 +197,8 @@ public:
     KConfig* config();
     void importFiles(QStringList& fileList, const QString &rootPath = QString());
 
+    static bool shuttingDown();
+
 protected:
     virtual void keyPressEvent(QKeyEvent* e);
     virtual void keyReleaseEvent(QKeyEvent* e);
@@ -517,6 +519,7 @@ private:
 
     QPointer<DiagramPrintPage> m_printSettings; ///< printer diagram settings
     QPrinter *m_printer;               ///< print instance
+    static bool s_shuttingDown;
 
 signals:
     void sigCutSuccessful();
