@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2014                                               *
+ *   copyright (C) 2002-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -515,7 +515,8 @@ void UMLObject::setUMLStereotype(UMLStereotype *stereo)
     }
     m_pStereotype = stereo;
     // TODO: don't emit modified() if predefined folder
-    emitModified();
+    if (!UMLApp::shuttingDown())
+        emitModified();
 }
 
 /**
@@ -972,7 +973,7 @@ bool UMLObject::loadFromXMI1(QDomElement & element)
         if (m_BaseType == ot_Role) {
             // Some older Umbrello versions had a problem with xmi.id's
             // of other objects being reused for the UMLRole, see e.g.
-            // attachment 21179 at http://bugs.kde.org/147988 .
+            // attachment 21179 at https://bugs.kde.org/147988 .
             // If the xmi.id is already being used then we generate a new one.
             UMLObject *o = umldoc->findObjectById(nId);
             if (o) {
