@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2014                                               *
+ *   copyright (C) 2002-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -69,7 +69,7 @@ class DiagramPrintPage;
  * files.
  *
  * @author Paul Hensgen   <phensgen@techie.com>
- * Bugs and comments to umbrello-devel@kde.org or http://bugs.kde.org
+ * Bugs and comments to umbrello-devel@kde.org or https://bugs.kde.org
  */
 class UMLDoc : public QObject
 {
@@ -194,13 +194,14 @@ public:
     UMLClassifierList classesAndInterfaces(bool includeNested = true);
     UMLEntityList entities(bool includeNested = true);
     UMLFolder * datatypeFolder() const;
-    UMLClassifierList datatypes();
+    UMLClassifierList datatypes(bool includeInactive = false);
     UMLAssociationList associations();
     UMLPackageList packages(bool includeNested = true, Uml::ModelType::Enum model = Uml::ModelType::Logical);
 
     void print(QPrinter * pPrinter, DiagramPrintPage * selectPage);
 
     UMLViewList viewIterator();
+    UMLViewList views(Uml::DiagramType::Enum type = Uml::DiagramType::Undefined);
 
     bool assignNewIDs(UMLObject* obj);
 
@@ -237,6 +238,7 @@ public:
 
     void addDefaultDatatypes();
     void createDatatype(const QString &name);
+    void removeDatatype(const QString &name);
 
     UMLStereotype *createStereotype(const QString &name);
     UMLStereotype *findStereotype(const QString &name);
@@ -257,10 +259,15 @@ public:
     StereotypesModel *stereotypesModel();
     ObjectsModel *objectsModel();
 
+    void setLoadingError(const QString &text);
+
 private:
     void initSaveTimer();
     void createDatatypeFolder();
 
+    class Private;
+    Private *m_d;
+
     /**
      * Array of predefined root folders.
      */
@@ -275,7 +282,7 @@ private:
     /**
      * The UMLDoc is the sole owner of all stereotypes.
      * UMLStereotype instances are reference counted.
-     * When an UMLStereotype is no longer referenced anywhere,
+     * When a UMLStereotype is no longer referenced anywhere,
      * its refcount drops to zero. It is then removed from the
      * m_stereoList and it is physically deleted.
      */
