@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2014                                               *
+ *   copyright (C) 2002-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -41,7 +41,7 @@ class UMLDragData;
  *
  * @short  Displays the list view for the program.
  * @author Paul Hensgen    <phensgen@techie.com>
- * Bugs and comments to umbrello-devel@kde.org or http://bugs.kde.org
+ * Bugs and comments to umbrello-devel@kde.org or https://bugs.kde.org
  */
 class UMLListView : public QTreeWidget
 {
@@ -105,8 +105,8 @@ public:
 
     UMLListViewItem::ListViewType rootViewType(UMLListViewItem *item);
 
-    void saveToXMI(QDomDocument & qDoc, QDomElement & qElement);
-    bool loadFromXMI(QDomElement & element);
+    void saveToXMI1(QDomDocument & qDoc, QDomElement & qElement);
+    bool loadFromXMI1(QDomElement & element);
     bool loadChildrenFromXMI(UMLListViewItem * parent, QDomElement & element);
 
     friend QDebug operator<<(QDebug out, const UMLListView& view);
@@ -178,6 +178,7 @@ private:
     UMLListViewItem* m_rv;         ///< root view (home)
     UMLListViewItem* m_lv[Uml::ModelType::N_MODELTYPES];  ///< predefined list view roots
     UMLListViewItem* m_datatypeFolder;
+    UMLListViewItem* m_settingsFolder; ///< settings root
     UMLDoc*          m_doc;
     bool             m_bStartedCut;
     bool             m_bStartedCopy;
