@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2006-2014                                               *
+ *   copyright (C) 2006-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -94,8 +94,7 @@ void UMLViewImageExporterAll::exportViews(const UMLViewList &views)
     if (m_dialog->m_kURL->url().isEmpty()) {
 #if QT_VERSION >= 0x050000
         QUrl directory(umlDoc->url());
-        directory.adjusted(QUrl::RemoveFilename);
-        m_dialog->m_kURL->setUrl(directory);
+        m_dialog->m_kURL->setUrl(directory.adjusted(QUrl::RemoveFilename));
 #else
         m_dialog->m_kURL->setUrl(umlDoc->url().directory());
 #endif
@@ -105,20 +104,16 @@ void UMLViewImageExporterAll::exportViews(const UMLViewList &views)
         return;
     }
 
-#if QT_VERSION >= 0x050000
-    app->setImageMimeType(m_dialog->m_imageType->currentText());
-#else
-    app->setImageMimeType(m_dialog->m_imageType->currentFilter());
-#endif
-
+    app->setImageMimeType(m_dialog->m_imageType->currentType());
+    float resolution = m_dialog->m_imageResolution->currentResolution();
     // export all views
     umlDoc->writeToStatusBar(i18n("Exporting all views..."));
-    QStringList errors = UMLViewImageExporterModel().exportViews(views,
+    QStringList errors = UMLViewImageExporterModel(resolution).exportViews(views,
 #if QT_VERSION >= 0x050000
-                                UMLViewImageExporterModel::mimeTypeToImageType(m_dialog->m_imageType->currentText()),
+                                UMLViewImageExporterModel::mimeTypeToImageType(m_dialog->m_imageType->currentType()),
                                 QUrl(m_dialog->m_kURL->url()),
 #else
-                                UMLViewImageExporterModel::mimeTypeToImageType(m_dialog->m_imageType->currentFilter()),
+                                UMLViewImageExporterModel::mimeTypeToImageType(m_dialog->m_imageType->currentType()),
                                 KUrl(m_dialog->m_kURL->url()),
 #endif
                                 m_dialog->m_useFolders->isChecked());
