@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2006-2014                                               *
+ *   copyright (C) 2006-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -21,12 +21,21 @@
 #include "umlview.h"
 
 // kde include files
-#include <klocale.h>
-#include <ktemporaryfile.h>
+#if QT_VERSION >= 0x050000
+#include <KIO/Job>
+#include <KJobWidgets>
+#include <KIO/MkdirJob>
+#else
 #include <kio/netaccess.h>
+#endif
+#if QT_VERSION < 0x050000
+#include <ktemporaryfile.h>
+#endif
+#include <KLocalizedString>
 
 // include files for Qt
 #include <QApplication>
+#include <QDesktopWidget>
 #include <QDir>
 #include <QImage>
 #include <QImageWriter>
@@ -36,6 +45,9 @@
 #include <QRect>
 #include <QRegExp>
 #include <QSvgGenerator>
+#if QT_VERSION >= 0x050000
+#include <QTemporaryFile>
+#endif
 
 // system includes
 #include <cmath>
@@ -163,8 +175,10 @@ QString UMLViewImageExporterModel::mimeTypeToImageType(const QString& mimeType)
 
 /**
  * Constructor for UMLViewImageExporterModel.
+ * @param resolution resolution of export in DPI (default 0.0 means export type related default)
  */
-UMLViewImageExporterModel::UMLViewImageExporterModel()
+UMLViewImageExporterModel::UMLViewImageExporterModel(float resolution)
+  : m_resolution(resolution)
 {
 }
 
@@ -176,7 +190,7 @@ UMLViewImageExporterModel::~UMLViewImageExporterModel()
 }
 
 /**
- * Exports all the views in the document to the directory specified in the url
+ * Exports views in the document to the directory specified in the url
  * using the 'imageType' for the images.
  * The name of the exported images will be like their view's name and using the
  * 'imageType' as extension.
@@ -197,17 +211,19 @@ UMLViewImageExporterModel::~UMLViewImageExporterModel()
  * @return A QStringList with all the error messages that occurred during export.
  *         If the list is empty, all the views were exported successfully.
  */
-QStringList UMLViewImageExporterModel::exportAllViews(const QString &imageType, const KUrl &directory, bool useFolders) const
+QStringList UMLViewImageExporterModel::exportViews(const UMLViewList &views, const QString &imageType, const QUrl &directory, bool useFolders) const
 {
-    UMLApp *app = UMLApp::app();
-
     // contains all the error messages returned by exportView calls
     QStringList errors;
 
-    UMLViewList views = app->document()->viewIterator();
     foreach (UMLView *view, views) {
+#if QT_VERSION >= 0x050000
+        QUrl url = QUrl::fromLocalFile(directory.path() + QLatin1Char('/') +
+                 getDiagramFileName(view->umlScene(), imageType, useFolders));
+#else
         KUrl url = directory;
         url.addPath(getDiagramFileName(view->umlScene(), imageType, useFolders));
+#endif
 
         QString returnString = exportView(view->umlScene(), imageType, url);
         if (!returnString.isNull()) {
@@ -234,7 +250,11 @@ QStringList UMLViewImageExporterModel::exportAllViews(const QString &imageType,
  * @return  The error message if some problem occurred when exporting, or
  *          QString() if all went fine.
  */
+#if QT_VERSION >= 0x050000
+QString UMLViewImageExporterModel::exportView(UMLScene* scene, const QString &imageType, const QUrl &url) const
+#else
 QString UMLViewImageExporterModel::exportView(UMLScene* scene, const QString &imageType, const KUrl &url) const
+#endif
 {
     if (!scene) {
         return i18n("Empty scene");
@@ -242,14 +262,22 @@ QString UMLViewImageExporterModel::exportView(UMLScene* scene, const QString &im
 
     // create the needed directories
     if (!prepareDirectory(url)) {
+#if QT_VERSION >= 0x050000
+        return i18n("Cannot create directory: %1", url.path());
+#else
         return i18n("Cannot create directory: %1", url.directory());
+#endif
     }
 
     // The fileName will be used when exporting the image. If the url isn't local,
     // the fileName is the name of a temporal local file to export the image to, and then
     // upload it to its destiny
     QString fileName;
+#if QT_VERSION >= 0x050000
+    QTemporaryFile tmpFile;
+#else
     KTemporaryFile tmpFile;
+#endif
     if (url.isLocalFile()) {
         fileName = url.toLocalFile();
     } else {
@@ -257,11 +285,6 @@ QString UMLViewImageExporterModel::exportView(UMLScene* scene, const QString &im
         fileName = tmpFile.fileName();
     }
 
-    QRectF rect = scene->diagramRect();
-    if (rect.isEmpty()) {
-        return i18n("Cannot save an empty diagram");
-    }
-
     // exporting the view to the file
     if (!exportViewTo(scene, imageType, fileName)) {
         return i18n("A problem occurred while saving diagram in %1", fileName);
@@ -269,7 +292,14 @@ QString UMLViewImageExporterModel::exportView(UMLScene* scene, const QString &im
 
     // if the file wasn't local, upload the temp file to the target
     if (!url.isLocalFile()) {
+#if QT_VERSION >= 0x050000
+        KIO::FileCopyJob *job = KIO::file_copy(QUrl::fromLocalFile(tmpFile.fileName()), url);
+        KJobWidgets::setWindow(job, UMLApp::app());
+        job->exec();
+        if (job->error()) {
+#else
         if (!KIO::NetAccess::upload(tmpFile.fileName(), url, UMLApp::app())) {
+#endif
             return i18n("There was a problem saving file: %1", url.path());
         }
     }
@@ -289,7 +319,7 @@ QString UMLViewImageExporterModel::getDiagramFileName(UMLScene* scene, const QSt
     if (scene) {
         if (useFolders) {
             qApp->processEvents();  //:TODO: still needed ???
-            return Model_Utils::treeViewBuildDiagramName(scene->ID());
+            return Model_Utils::treeViewBuildDiagramName(scene->ID()) + QLatin1Char('.') + imageType.toLower();
         }
         else {
             return scene->name() + QLatin1Char('.') + imageType.toLower();
@@ -309,9 +339,33 @@ QString UMLViewImageExporterModel::getDiagramFileName(UMLScene* scene, const QSt
  * @return True if the operation was successful,
  *         false if the directory didn't exist and couldn't be created.
  */
+#if QT_VERSION >= 0x050000
+bool UMLViewImageExporterModel::prepareDirectory(const QUrl &url) const
+#else
 bool UMLViewImageExporterModel::prepareDirectory(const KUrl &url) const
+#endif
 {
     // the KUrl is copied to get protocol, user and so on and then the path is cleaned
+#if QT_VERSION >= 0x050000
+    QUrl directory = url;
+    directory.setPath(QString());
+
+    // creates the directory and any needed parent directories
+    QStringList dirs = url.adjusted(QUrl::RemoveFilename).path().split(QDir::separator(), QString::SkipEmptyParts);
+    for (QStringList::ConstIterator it = dirs.constBegin() ; it != dirs.constEnd(); ++it) {
+        directory.setPath(directory.path() + QLatin1Char('/') + *it);
+        KIO::StatJob *statJob = KIO::stat(directory, KIO::StatJob::SourceSide, 0);
+        KJobWidgets::setWindow(statJob, UMLApp::app());
+        statJob->exec();
+        if (statJob->error()) {
+
+            KIO::MkdirJob* job = KIO::mkdir(directory);
+            if (!job->exec()) {
+                return false;
+            }
+        }
+    }
+#else
     KUrl directory = url;
     directory.setPath(QString());
 
@@ -327,6 +381,7 @@ bool UMLViewImageExporterModel::prepareDirectory(const KUrl &url) const
             }
         }
     }
+#endif
 
     return true;
 }
@@ -356,7 +411,7 @@ bool UMLViewImageExporterModel::exportViewTo(UMLScene* scene, const QString &ima
             return false;
         }
     } else if (imageMimeType == QLatin1String("image/x-eps")) {
-        if (!exportViewToEps(scene, fileName, true)) {
+        if (!exportViewToEps(scene, fileName)) {
             return false;
         }
     } else if (imageMimeType == QLatin1String("image/svg+xml")) {
@@ -399,66 +454,55 @@ bool UMLViewImageExporterModel::exportViewToDot(UMLScene* scene, const QString &
  *
  * @param scene    The scene to export.
  * @param fileName The name of the file where the image will be saved.
- * @param isEPS    The file is an eps file and needs adjusting
- *                 of the eps bounding box values.
  * @return True if the operation was successful,
  *         false if a problem occurred while exporting.
  */
-bool UMLViewImageExporterModel::exportViewToEps(UMLScene* scene, const QString &fileName, bool isEPS) const
+bool UMLViewImageExporterModel::exportViewToEps(UMLScene* scene, const QString &fileName) const
 {
     if (!scene) {
         uWarning() << "Scene is null!";
         return false;
     }
 
-    bool exportSuccessful = true;
-
-    // print the image to a normal postscript file,
-    // do not clip so that everything ends up in the file
-    // regardless of "paper size"
-
-    // because we want to work with postscript
-    // user-coordinates, set to the resolution
-    // of the printer (which should be 72dpi here)
-    QPrinter *printer;
-
-    if (isEPS == false) {
-        printer = new QPrinter(QPrinter::PrinterResolution);
-    } else {
-        printer = new QPrinter(QPrinter::ScreenResolution);
+    qreal border = 0.01; // mm
+    QRectF rect = scene->diagramRect();
+    if (rect.isEmpty()) {
+        rect = QRectF(0,0, 10, 10);
     }
-    printer->setOutputFileName(fileName);
-    printer->setOutputFormat(QPrinter::PostScriptFormat);
-    printer->setColorMode(QPrinter::Color);
+
+    QSizeF paperSize(rect.size() * 25.4f / qApp->desktop()->logicalDpiX());
+
+    QPrinter printer(QPrinter::ScreenResolution);
+    printer.setOutputFileName(fileName);
+#if QT_VERSION >= 0x050000
+    printer.setOutputFormat(QPrinter::PdfFormat);
+#else
+    printer.setOutputFormat(QPrinter::PostScriptFormat);
+#endif
+    printer.setColorMode(QPrinter::Color);
+    printer.setPaperSize(paperSize, QPrinter::Millimeter);
+    printer.setPageMargins(paperSize.width() * border, paperSize.height() * border, 0, 0, QPrinter::Millimeter);
+    printer.setResolution(qApp->desktop()->logicalDpiX());
+    printer.setOrientation(paperSize.width() < paperSize.height() ? QPrinter::Landscape : QPrinter::Portrait);
 
     // do not call printer.setup(); because we want no user
     // interaction here
-    QPainter *painter = new QPainter(printer);
+    QPainter painter(&printer);
+
+    // add border around image
+    painter.scale(1 - border, 1 - border);
 
     // make sure the widget sizes will be according to the
     // actually used printer font, important for diagramRect()
     // and the actual painting
-    scene->forceUpdateWidgetFontMetrics(painter);
+    scene->forceUpdateWidgetFontMetrics(&painter);
 
-    QRectF rect = scene->diagramRect();
-    painter->translate(-rect.x(), -rect.y());
-    scene->getDiagram(*painter, rect);
+    scene->getDiagram(painter, rect);
 
-    int resolution = printer->resolution();
-
-    // delete painter and printer before we try to open and fix the file
-    delete painter;
-    delete printer;
-    if (isEPS) {
-        // modify bounding box from screen to eps resolution.
-        rect.setWidth(int(ceil(rect.width() * 72.0/resolution)));
-        rect.setHeight(int(ceil(rect.height() * 72.0/resolution)));
-        exportSuccessful = fixEPS(fileName, rect);
-    }
     // next painting will most probably be to a different device (i.e. the screen)
     scene->forceUpdateWidgetFontMetrics(0);
 
-    return exportSuccessful;
+    return true;
 }
 
 /**
@@ -478,10 +522,14 @@ bool UMLViewImageExporterModel::exportViewToSvg(UMLScene* scene, const QString &
 
     bool exportSuccessful;
     QRectF rect = scene->diagramRect();
+    if (rect.isEmpty()) {
+        rect = QRectF(0,0, 10, 10);
+    }
 
     QSvgGenerator generator;
     generator.setFileName(fileName);
     generator.setSize(rect.toRect().size());
+    generator.setResolution(qApp->desktop()->logicalDpiX());
     generator.setViewBox(QRect(0, 0, rect.width(), rect.height()));
     QPainter painter(&generator);
 
@@ -526,7 +574,13 @@ bool UMLViewImageExporterModel::exportViewToPixmap(UMLScene* scene, const QStrin
     }
 
     QRectF rect = scene->diagramRect();
-    QPixmap diagram(rect.width(), rect.height());
+    if (rect.isEmpty()) {
+        rect = QRectF(0,0, 10, 10);
+    }
+
+    float scale = m_resolution != 0.0 ? m_resolution / qApp->desktop()->logicalDpiX() : 72.0f / qApp->desktop()->logicalDpiX();
+    QSizeF size = rect.size() * scale;
+    QPixmap diagram(size.toSize());
     scene->getDiagram(diagram, rect);
     bool exportSuccessful = diagram.save(fileName, qPrintable(imageType.toUpper()));
     DEBUG(DBG_IEM) << "saving to file " << fileName
@@ -536,56 +590,3 @@ bool UMLViewImageExporterModel::exportViewToPixmap(UMLScene* scene, const QStrin
                    << ", successful=" << exportSuccessful;
     return exportSuccessful;
 }
-
-/**
- * Fix the file 'fileName' to be a valid EPS containing the
- * specified area (rect) of the diagram.
- * Corrects the bounding box.
- *
- * @return True if the operation was successful,
- *         false if a problem occurred while exporting.
- */
-bool UMLViewImageExporterModel::fixEPS(const QString &fileName, const QRectF& rect) const
-{
-    // now open the file and make a correct eps out of it
-    QFile epsfile(fileName);
-    if (! epsfile.open(QIODevice::ReadOnly)) {
-        return false;
-    }
-    // read
-    QTextStream ts(&epsfile);
-    QString fileContent = ts.readAll();
-    epsfile.close();
-    
-    // read information
-    QRegExp rx(QLatin1String("%%BoundingBox:\\s*(-?[\\d\\.:]+)\\s*(-?[\\d\\.:]+)\\s*(-?[\\d\\.:]+)\\s*(-?[\\d\\.:]+)"));
-    const int pos = rx.indexIn(fileContent);
-    if (pos < 0) {
-        uError() << fileName << ": cannot find %%BoundingBox";
-        return false;
-    }
-    
-    // write new content to file
-    if (! epsfile.open(QIODevice::WriteOnly | QIODevice::Truncate)) {
-        uError() << fileName << ": cannot open file for writing";
-        return false;
-    }
-    
-    // be careful when rounding (ceil/floor) the BB, these roundings
-    // were mainly obtained experimentally...
-    const double epsleft = rx.cap(1).toFloat();
-    const double epstop = rx.cap(4).toFloat();
-    const int left = int(floor(epsleft));
-    const int right = int(ceil(epsleft)) + rect.width();
-    const int top = int(ceil(epstop)) + 1;
-    const int bottom = int(floor(epstop)) - rect.height() + 1;
-    
-    // modify content
-    fileContent.replace(pos, rx.cap(0).length(),
-                        QString::fromLatin1("%%BoundingBox: %1 %2 %3 %4").arg(left).arg(bottom).arg(right).arg(top));
-    
-    ts << fileContent;
-    epsfile.close();
-    
-    return true;
-}
