@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2004-2014                                               *
+ *   copyright (C) 2004-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -18,6 +18,8 @@
 #include "classifier.h"
 #include "cmds.h"
 #include "debug_utils.h"
+#include "diagram_utils.h"
+#include "dialog_utils.h"
 #include "instance.h"
 #include "listpopupmenu.h"
 #include "object_factory.h"
@@ -26,6 +28,7 @@
 #include "uml.h"
 #include "umldoc.h"
 #include "umlview.h"
+#include "widget_utils.h"
 
 // qt includes
 #include <QPainter>
@@ -43,9 +46,10 @@ const int ClassifierWidget::SOCKET_INCREMENT = 10;
  */
 ClassifierWidget::ClassifierWidget(UMLScene * scene, UMLClassifier *c)
   : UMLWidget(scene, WidgetBase::wt_Class, c),
-    m_pAssocWidget(0),
-    m_pInterfaceName(0)
+    m_pAssocWidget(nullptr),
+    m_pInterfaceName(nullptr)
 {
+    DiagramProxyWidget::setShowLinkedDiagram(false);
     const Settings::OptionState& ops = m_scene->optionState();
     setVisualPropertyCmd(ShowVisibility, ops.classState.showVisibility);
     setVisualPropertyCmd(ShowOperations, ops.classState.showOps);
@@ -95,8 +99,8 @@ ClassifierWidget::ClassifierWidget(UMLScene * scene, UMLClassifier *c)
  */
 ClassifierWidget::ClassifierWidget(UMLScene * scene, UMLPackage *o)
   : UMLWidget(scene, WidgetBase::wt_Package, o),
-    m_pAssocWidget(0),
-    m_pInterfaceName(0)
+    m_pAssocWidget(nullptr),
+    m_pInterfaceName(nullptr)
 {
     const Settings::OptionState& ops = m_scene->optionState();
     setVisualPropertyCmd(ShowVisibility, ops.classState.showVisibility);
@@ -132,7 +136,7 @@ ClassifierWidget::~ClassifierWidget()
         m_pAssocWidget->removeAssocClassLine();
     if (m_pInterfaceName) {
         delete m_pInterfaceName;
-        m_pInterfaceName = 0;
+        m_pInterfaceName = nullptr;
     }
 }
 
@@ -275,7 +279,7 @@ void ClassifierWidget::setVisualPropertyCmd(VisualProperty property, bool enable
             return;
         }
 
-        // Call setVisualProperties appropriately based on enbable.
+        // Call setVisualProperties appropriately based on enable.
         if (enable) {
             setVisualProperties(visualProperties() | property);
         } else {
@@ -613,6 +617,9 @@ QSizeF ClassifierWidget::calculateSize(bool withExtensions /* = true */) const
     // allow for width margin
     width += defaultMargin * 2;
 
+    if (DiagramProxyWidget::linkedDiagram() || DiagramProxyWidget::diagramLink() != Uml::ID::None)
+        width += 2 * DiagramProxyWidget::iconRect().width();
+
     return QSizeF(width, height);
 }
 
@@ -760,9 +767,10 @@ void ClassifierWidget::paint(QPainter *painter, const QStyleOptionGraphicsItem *
         painter->setFont(font);
         const int x = width() - templatesBoxSize.width() + defaultMargin;
         int y = defaultMargin;
+        const int templateWidth = templatesBoxSize.width() - 2 * defaultMargin;
         foreach (UMLTemplate *t, tlist) {
             QString text = t->toString(Uml::SignatureType::NoSig, visualProperty(ShowStereotype));
-            painter->drawText(x, y, fm.size(0, text).width(), fontHeight, Qt::AlignVCenter, text);
+            painter->drawText(x, y, templateWidth, fontHeight, Qt::AlignVCenter, text);
             y += fontHeight;
         }
     }
@@ -827,7 +835,7 @@ void ClassifierWidget::paint(QPainter *painter, const QStyleOptionGraphicsItem *
             if (brect.width() > width() + 2*defaultMargin)
                 brect.setWidth(width()-2*defaultMargin);
             brect.adjust(textX, bodyOffsetY, textX, bodyOffsetY);
-            painter->drawText(brect, Qt::AlignCenter | Qt::TextWordWrap, documentation());
+            painter->drawText(brect, Qt::AlignLeft | Qt::TextWordWrap, documentation());
             bodyOffsetY += brect.height();
         }
         else
@@ -845,10 +853,10 @@ void ClassifierWidget::paint(QPainter *painter, const QStyleOptionGraphicsItem *
         if (numAtts > 0) {
             if (baseType() == WidgetBase::wt_Instance) {
                 drawMembers(painter, UMLObject::ot_InstanceAttribute, m_attributeSignature, textX,
-                            bodyOffsetY, fontHeight);
+                            bodyOffsetY, textWidth, fontHeight);
             } else {
                 drawMembers(painter, UMLObject::ot_Attribute, m_attributeSignature, textX,
-                            bodyOffsetY, fontHeight);
+                            bodyOffsetY, textWidth, fontHeight);
             }
             bodyOffsetY += fontHeight * numAtts;
         }
@@ -866,10 +874,14 @@ void ClassifierWidget::paint(QPainter *painter, const QStyleOptionGraphicsItem *
         const int numOps = displayedOperations();
         if (numOps >= 0) {
             drawMembers(painter, UMLObject::ot_Operation, m_operationSignature, textX,
-                        bodyOffsetY, fontHeight);
+                        bodyOffsetY, textWidth, fontHeight);
         }
     }
 
+    if (DiagramProxyWidget::linkedDiagram()) {
+        DiagramProxyWidget::paint(painter, option, widget);
+    }
+
     UMLWidget::paint(painter, option, widget);
 }
 
@@ -1063,10 +1075,11 @@ QSize ClassifierWidget::calculateAsPackageSize() const
  * @param sigType    Governs details of the member display.
  * @param x          X coordinate at which to draw the texts.
  * @param y          Y coordinate at which text drawing commences.
- * @param fontHeight The font height.
+ * @param width      The text width.
+ * @param height     The text height.
  */
 void ClassifierWidget::drawMembers(QPainter * painter, UMLObject::ObjectType ot, Uml::SignatureType::Enum sigType,
-                                   int x, int y, int fontHeight)
+                                   int x, int y, int width, int height)
 {
     UMLClassifier *umlc = classifier();
     if (!umlc) {
@@ -1084,12 +1097,11 @@ void ClassifierWidget::drawMembers(QPainter * painter, UMLObject::ObjectType ot,
         f.setItalic(obj->isAbstract());
         f.setUnderline(obj->isStatic());
         painter->setFont(f);
-        QFontMetrics fontMetrics(f);
-        painter->drawText(x, y, fontMetrics.size(0, text).width(), fontHeight, Qt::AlignVCenter, text);
+        painter->drawText(x, y, width, height, Qt::AlignVCenter, text);
         f.setItalic(false);
         f.setUnderline(false);
         painter->setFont(f);
-        y += fontHeight;
+        y += height;
     }
     painter->setClipping(false);
 }
@@ -1105,13 +1117,13 @@ void ClassifierWidget::drawMembers(QPainter * painter, UMLObject::ObjectType ot,
  */
 UMLWidget* ClassifierWidget::onWidget(const QPointF &p)
 {
-    if (UMLWidget::onWidget(p) != 0)
+    if (UMLWidget::onWidget(p) != nullptr)
         return this;
     if (getDrawAsCircle() && m_pInterfaceName) {
         uDebug() << "floatingtext: " << m_pInterfaceName->text();
         return m_pInterfaceName->onWidget(p);
     }
-    return 0;
+    return nullptr;
 }
 
 /**
@@ -1123,7 +1135,7 @@ UMLWidget* ClassifierWidget::widgetWithID(Uml::ID::Type id)
         return this;
     if (getDrawAsCircle() && m_pInterfaceName && m_pInterfaceName->widgetWithID(id))
         return m_pInterfaceName;
-    return 0;
+    return nullptr;
 }
 
 void ClassifierWidget::setDocumentation(const QString &doc)
@@ -1243,31 +1255,6 @@ void ClassifierWidget::changeToPackage()
     update();
 }
 
-/**
- * Extends base method to adjust also the association of a class
- * association.
- * Executes the base method and then, if file isn't loading and the
- * classifier acts as a class association, the association position is
- * updated.
- * TODO: This is never called.
- *
- *  param x The x-coordinate.
- *  param y The y-coordinate.
- */
-//void ClassifierWidget::adjustAssociations(int x, int y)
-//{
-//    DEBUG(DBG_SRC) << "x=" << x << " / y=" << y;
-//    UMLWidget::adjustAssocs(x, y);
-
-//    if (m_doc->loading() || m_pAssocWidget == 0) {
-//        return;
-//    }
-
-//    //:TODO: the following is also called from UMLWidgetr::ajdustAssocs(...)
-//    //       and then AssociationWidget::widgetMoved(...)
-//    //m_pAssocWidget->computeAssocClassLine();
-//}
-
 /**
  * Loads the "classwidget" or "interfacewidget" XML element.
  */
@@ -1276,6 +1263,9 @@ bool ClassifierWidget::loadFromXMI1(QDomElement & qElement)
     if (!UMLWidget::loadFromXMI1(qElement)) {
         return false;
     }
+    if (DiagramProxyWidget::linkedDiagram())
+        DiagramProxyWidget::setShowLinkedDiagram(false);
+
     bool loadShowAttributes = true;
     if (umlObject() && (umlObject()->isUMLPackage() || umlObject()->isUMLInstance())) {
         loadShowAttributes = false;
@@ -1315,7 +1305,7 @@ bool ClassifierWidget::loadFromXMI1(QDomElement & qElement)
     if (!element.isNull()) {
         QString tag = element.tagName();
         if (tag == QLatin1String("floatingtext")) {
-            if (m_pInterfaceName == 0) {
+            if (m_pInterfaceName == nullptr) {
                 m_pInterfaceName = new FloatingTextWidget(m_scene,
                                                           Uml::TextRole::Floating,
                                                           name(), Uml::ID::Reserved);
@@ -1324,7 +1314,7 @@ bool ClassifierWidget::loadFromXMI1(QDomElement & qElement)
             if (!m_pInterfaceName->loadFromXMI1(element)) {
                 // Most likely cause: The FloatingTextWidget is empty.
                 delete m_pInterfaceName;
-                m_pInterfaceName = 0;
+                m_pInterfaceName = nullptr;
             } else {
                 m_pInterfaceName->activate();
                 m_pInterfaceName->update();
@@ -1481,7 +1471,7 @@ void ClassifierWidget::slotMenuSelection(QAction* action)
         break;
 
     default:
-        UMLWidget::slotMenuSelection(action);
+        DiagramProxyWidget::slotMenuSelection(action);
         break;
     }
 }
@@ -1502,6 +1492,14 @@ void ClassifierWidget::slotShowOperations(bool state)
     setVisualProperty(ShowOperations, state);
 }
 
+void ClassifierWidget::mouseDoubleClickEvent(QGraphicsSceneMouseEvent *event)
+{
+    if (linkedDiagram())
+        DiagramProxyWidget::mouseDoubleClickEvent(event);
+    if (event->isAccepted())
+        UMLWidget::mouseDoubleClickEvent(event);
+}
+
 /**
  * Show a properties dialog for a ClassifierWidget
  */
