@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2014                                               *
+ *   copyright (C) 2002-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -34,6 +34,8 @@
 #include <QColorDialog>
 #endif
 
+DEBUG_REGISTER_DISABLED(NoteWidget)
+
 QPointer<NoteWidget> NoteWidget::s_pCurrentNote;
 
 /**
@@ -152,7 +154,7 @@ void NoteWidget::setNoteType(const QString& noteType)
 /**
  * Return the ID of the diagram hyperlinked to this note.
  *
- * @return  ID of an UMLView, or Uml::ID::None if no
+ * @return  ID of a UMLView, or Uml::ID::None if no
  *          hyperlink is set.
  */
 Uml::ID::Type NoteWidget::diagramLink() const
@@ -164,7 +166,7 @@ Uml::ID::Type NoteWidget::diagramLink() const
  * Set the ID of the diagram hyperlinked to this note.
  * To switch off the hyperlink, set this to Uml::id_None.
  *
- * @param viewID    ID of an UMLScene.
+ * @param viewID    ID of a UMLScene.
  */
 void NoteWidget::setDiagramLink(Uml::ID::Type viewID)
 {
