@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2014                                               *
+ *   copyright (C) 2002-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -25,7 +25,7 @@ class QPainter;
  * @short Displays a note box.
  * @author Paul Hensgen <phensgen@techie.com>
  * @see UMLWidget
- * Bugs and comments to umbrello-devel@kde.org or http://bugs.kde.org
+ * Bugs and comments to umbrello-devel@kde.org or https://bugs.kde.org
  */
 class NoteWidget : public UMLWidget
 {
@@ -59,10 +59,11 @@ public:
 
     void askForNoteType(UMLWidget* &targetWidget);
 
-    virtual void showPropertiesDialog();
+    virtual bool showPropertiesDialog();
 
     virtual bool loadFromXMI1(QDomElement & qElement);
     virtual void saveToXMI1(QDomDocument & qDoc, QDomElement & qElement);
+    virtual QSizeF minimumSize() const;
 
     static QPointer<NoteWidget> s_pCurrentNote;
 
@@ -70,7 +71,6 @@ public Q_SLOTS:
     void slotMenuSelection(QAction* action);
 
 protected:
-    virtual QSizeF minimumSize() const;
     virtual QSizeF calculateSize(bool withExtensions = true) const;
     void paintText(QPainter *painter);
     void paintTextWordWrap(QPainter *painter);
