@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2014                                                    *
+ *   copyright (C) 2014-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -22,7 +22,7 @@ class ChildWidgetPlacement;
  * @short Abstract base class for PinWidget and PortWidget
  * @author Oliver Kellogg
  * @see UMLWidget
- * Bugs and comments to umbrello-devel@kde.org or http://bugs.kde.org
+ * Bugs and comments to umbrello-devel@kde.org or https://bugs.kde.org
  */
 class PinPortBase : public UMLWidget
 {
@@ -37,6 +37,8 @@ public:
 
     virtual UMLWidget* ownerWidget() const;
 
+    void setInitialPosition(const QPointF &scenePos);
+
     void updateWidget();
     void setName(const QString &strName);
     void moveWidgetBy(qreal diffX, qreal diffY);
