@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2014                                               *
+ *   copyright (C) 2002-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -27,7 +27,7 @@ class ObjectWidget;
  *
  * @author Florence Mattler <florence.mattler@libertysurf.fr>
  *
- * Bugs and comments to umbrello-devel@kde.org or http://bugs.kde.org
+ * Bugs and comments to umbrello-devel@kde.org or https://bugs.kde.org
  */
 class PreconditionWidget : public UMLWidget
 {
@@ -44,10 +44,11 @@ public:
     bool activate(IDChangeLog* Log = 0);
     void resolveObjectWidget(IDChangeLog* log);
 
-    virtual void saveToXMI(QDomDocument& qDoc, QDomElement& qElement);
-    virtual bool loadFromXMI(QDomElement& qElement);
+    virtual void saveToXMI1(QDomDocument& qDoc, QDomElement& qElement);
+    virtual bool loadFromXMI1(QDomElement& qElement);
 
-    void setObjectWidget(ObjectWidget* widget);
+    ObjectWidget *objectWidget() const;
+    void setObjectWidget(ObjectWidget *objectWidget);
 
 public slots:
     void slotMenuSelection(QAction* action);
@@ -64,7 +65,6 @@ private:
     int m_nY;
 
     Uml::ID::Type m_widgetAId;
-    void loadObjectWidget();
 };
 
 #endif
