@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2014                                               *
+ *   copyright (C) 2002-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -31,6 +31,8 @@
 #include <QtGlobal>
 #include <QPointer>
 
+DEBUG_REGISTER_DISABLED(StateWidget)
+
 /**
  * Creates a State widget.
  *
@@ -199,17 +201,13 @@ void StateWidget::paint(QPainter *painter, const QStyleOptionGraphicsItem *optio
             painter->setFont(font);
             painter->drawText(STATE_MARGIN, 0, w - STATE_MARGIN * 2, fontHeight,
                               Qt::AlignCenter, name());
-            if (!m_linkedDiagram) {
+            if (!linkedDiagram()) {
                 m_size = QSizeF(fm.width(name()) + STATE_MARGIN * 2, fm.lineSpacing() + STATE_MARGIN);
             } else {
-                m_sceneRect = m_linkedDiagram->sceneRect().adjusted(-1,-1, 1, 1);
-                m_clientRect = rect().adjusted(STATE_MARGIN, fontHeight + STATE_MARGIN, - STATE_MARGIN, -STATE_MARGIN);
-                if (Tracer::instance()->isEnabled(QLatin1String(metaObject()->className()))) {
-                    painter->setPen(Qt::magenta);
-                    painter->drawRect(m_clientRect);
-                }
-                m_linkedDiagram->render(painter, m_clientRect, m_sceneRect);
-                m_size = QSizeF(qMax<qreal>(fm.width(m_linkedDiagram->name()), m_sceneRect.width()) + STATE_MARGIN * 2, fm.lineSpacing() + STATE_MARGIN + m_sceneRect.height());
+                DiagramProxyWidget::setClientRect(rect().adjusted(STATE_MARGIN, fontHeight + STATE_MARGIN, - STATE_MARGIN, -STATE_MARGIN));
+                DiagramProxyWidget::paint(painter, option, widget);
+                QSizeF size = DiagramProxyWidget::sceneRect().size();
+                m_size = QSizeF(qMax<qreal>(fm.width(linkedDiagram()->name()), size.width()) + STATE_MARGIN * 2, fm.lineSpacing() + STATE_MARGIN + size.height());
                 setSize(m_size);
             }
             setPenFromSettings(painter);
@@ -603,27 +601,8 @@ void StateWidget::slotMenuSelection(QAction* action)
         setDrawVertical(true);
         break;
 
-    case ListPopupMenu::mt_CombinedState:
-        {
-            QString diagramName = m_doc->createDiagramName(Uml::DiagramType::State);
-            Uml::CmdCreateDiagram* d = new Uml::CmdCreateDiagram(m_doc, Uml::DiagramType::State, diagramName);
-            UMLApp::app()->executeCommand(d);
-            setDiagramLink(d->view()->umlScene()->ID());
-            setStateType(Combined);
-        }
-        break;
-
-    case ListPopupMenu::mt_EditCombinedState:
-        if (!m_linkedDiagram) {
-            uError() << "no diagram id defined at widget '" << Uml::ID::toString(id()) << "'";
-            break;
-        }
-        m_linkedDiagram->setWidgetLink(this);
-        UMLApp::app()->document()->changeCurrentView(m_diagramLinkId);
-        break;
-
     default:
-        UMLWidget::slotMenuSelection(action);
+        DiagramProxyWidget::slotMenuSelection(action);
         break;
     }
 }
