@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2014                                               *
+ *   copyright (C) 2002-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -35,7 +35,7 @@ class QFontMetrics;
  *
  * @short The base class for graphical UML objects.
  * @author  Paul Hensgen <phensgen@techie.com>
- * Bugs and comments to umbrello-devel@kde.org or http://bugs.kde.org
+ * Bugs and comments to umbrello-devel@kde.org or https://bugs.kde.org
  */
 class UMLWidget : public WidgetBase, public DiagramProxyWidget
 {
@@ -61,11 +61,6 @@ public:
 
     bool operator==(const UMLWidget& other) const;
 
-    void setLocalID(Uml::ID::Type id);
-    Uml::ID::Type localID() const;
-
-    virtual UMLWidget* widgetWithID(Uml::ID::Type id);
-
     virtual QSizeF minimumSize() const;
     void setMinimumSize(const QSizeF &size);
 
@@ -138,8 +133,8 @@ public:
 
     void moveByLocal(qreal dx, qreal dy);
 
-    void removeAssoc(AssociationWidget* pAssoc);
-    void addAssoc(AssociationWidget* pAssoc);
+    virtual void removeAssoc(AssociationWidget* pAssoc);
+    virtual void addAssoc(AssociationWidget* pAssoc);
 
     AssociationWidgetList &associationWidgetList() const;
 
@@ -184,8 +179,6 @@ public:
 
     virtual void cleanup();
 
-    static bool widgetHasUMLObject(WidgetBase::WidgetType type);
-
     void updateGeometry(bool withAssocs = true);
 
     void clipSize();
@@ -305,7 +298,6 @@ protected:
 
     ///////////////// End of Data Loaded/Saved //////////////////////////
 
-    Uml::ID::Type  m_nLocalID;
     bool           m_startMove;
     QPointF        m_startMovePostion;
     QSizeF         m_startResizeSize;
