@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2006-2014                                               *
+ *   copyright (C) 2006-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -25,7 +25,7 @@ Uml::ID::Type m_uniqueID;
  */
 Uml::ID::Type gen()
 {
-    m_uniqueID = std::string(KRandom::randomString(12).toLatin1());
+    m_uniqueID = std::string('u' + KRandom::randomString(12).toLatin1());
     return m_uniqueID;
 }
 
